# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__MEASURE_BB_THICK_METADATA = Metadata(
    id="30e00fda87c675225a811b0f3e8ba20b8c2068e7.boutiques",
    name="@measure_bb_thick",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VMeasureBbThickOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__measure_bb_thick(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    maxfill: OutputPathType | None
    """Thickness/depth dataset"""
    bb_thick: OutputPathType | None
    """Volumetric thickness dataset"""
    bb_thick_smooth: OutputPathType | None
    """Smoothed volumetric thickness dataset"""
    bb_thick_niml: OutputPathType | None
    """Unsmoothed thickness mapped to surface nodes"""
    bb_thick_smooth_niml: OutputPathType | None
    """Smoothed thickness mapped to surface nodes"""
    maskset_output: OutputPathType | None
    """Mask dataset"""
    maskset_resampled: OutputPathType | None
    """Resampled mask dataset"""
    anat_surface: OutputPathType | None
    """Surface representation of mask volume"""
    quick_spec: OutputPathType | None
    """Simple specification file for surface to use with suma commands"""


def v__measure_bb_thick(
    maskset: InputPathType,
    surfset: InputPathType,
    outdir: str | None = None,
    resample: str | None = None,
    increment: float | None = None,
    surfsmooth: float | None = None,
    smoothmm: float | None = None,
    maxthick: float | None = None,
    depth_search: float | None = None,
    keep_temp_files: bool = False,
    balls_only: bool = False,
    surfsmooth_method: str | None = None,
    runner: Runner | None = None,
) -> VMeasureBbThickOutputs:
    """
    Compute thickness of mask using ball and box method.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@measure_bb_thick.html
    
    Args:
        maskset: Mask dataset for input.
        surfset: Surface dataset onto which to map thickness (e.g., pial/gray\
            matter surface).
        outdir: Output directory.
        resample: Resample input to mm in millimeters (e.g., half a voxel or\
            'auto'). No resampling is done by default.
        increment: Test thickness at increments of sub-voxel distance. Default\
            is 1/4 voxel minimum distance (in-plane).
        surfsmooth: Smooth surface map of thickness by mm millimeters. Default\
            is 6 mm.
        smoothmm: Smooth volume by mm FWHM in mask. Default is 2*voxelsize of\
            mask or resampled mask.
        maxthick: Search for maximum thickness value of mm millimeters. Default\
            is 6 mm.
        depth_search: Map to surface by looking for max along mm millimeter\
            normal vectors. Default is 3 mm.
        keep_temp_files: Do not delete the intermediate files (for testing).
        balls_only: Calculate only with spheres and skip boxes.
        surfsmooth_method: Heat method used for smoothing surfaces. Default is\
            HEAT_07 but HEAT_05 is also useful for models.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VMeasureBbThickOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__MEASURE_BB_THICK_METADATA)
    cargs = []
    cargs.append("@measure_bb_thick")
    cargs.append("-maskset")
    cargs.append(execution.input_file(maskset))
    cargs.append("-surfset")
    cargs.append(execution.input_file(surfset))
    cargs.append("-outdir")
    if outdir is not None:
        cargs.append(outdir)
    if resample is not None:
        cargs.extend([
            "-resample",
            resample
        ])
    if increment is not None:
        cargs.extend([
            "-increment",
            str(increment)
        ])
    if surfsmooth is not None:
        cargs.extend([
            "-surfsmooth",
            str(surfsmooth)
        ])
    if smoothmm is not None:
        cargs.extend([
            "-smoothmm",
            str(smoothmm)
        ])
    if maxthick is not None:
        cargs.extend([
            "-maxthick",
            str(maxthick)
        ])
    if depth_search is not None:
        cargs.extend([
            "-depthsearch",
            str(depth_search)
        ])
    if keep_temp_files:
        cargs.append("-keep_temp_files")
    if balls_only:
        cargs.append("-balls_only")
    if surfsmooth_method is not None:
        cargs.extend([
            "-surfsmooth_method",
            surfsmooth_method
        ])
    ret = VMeasureBbThickOutputs(
        root=execution.output_file("."),
        maxfill=execution.output_file(outdir + "/maxfill.nii.gz") if (outdir is not None) else None,
        bb_thick=execution.output_file(outdir + "/bb_thick.nii.gz") if (outdir is not None) else None,
        bb_thick_smooth=execution.output_file(outdir + "/bb_thick_smooth.nii.gz") if (outdir is not None) else None,
        bb_thick_niml=execution.output_file(outdir + "/bb_thick.niml.dset") if (outdir is not None) else None,
        bb_thick_smooth_niml=execution.output_file(outdir + "/bb_thick_smooth.niml.dset") if (outdir is not None) else None,
        maskset_output=execution.output_file(outdir + "/maskset.nii.gz") if (outdir is not None) else None,
        maskset_resampled=execution.output_file(outdir + "/maskset_rs.nii.gz") if (outdir is not None) else None,
        anat_surface=execution.output_file(outdir + "/anat.gii") if (outdir is not None) else None,
        quick_spec=execution.output_file(outdir + "/quick.spec") if (outdir is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VMeasureBbThickOutputs",
    "V__MEASURE_BB_THICK_METADATA",
    "v__measure_bb_thick",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

VOLUME_PARCEL_SMOOTHING_METADATA = Metadata(
    id="f27c64a6c0852328393dc55d6325df0de41f496c.boutiques",
    name="volume-parcel-smoothing",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class VolumeParcelSmoothingOutputs(typing.NamedTuple):
    """
    Output object returned when calling `volume_parcel_smoothing(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_out: OutputPathType
    """the output volume"""


def volume_parcel_smoothing(
    data_volume: InputPathType,
    label_volume: InputPathType,
    kernel: float,
    volume_out: str,
    opt_fwhm: bool = False,
    opt_fix_zeros: bool = False,
    opt_subvolume_subvol: str | None = None,
    runner: Runner | None = None,
) -> VolumeParcelSmoothingOutputs:
    """
    Smooth parcels in a volume separately.
    
    The volume is smoothed within each label in the label volume using data only
    from within the label. Equivalent to running volume smoothing with ROIs
    matching each label separately, then adding the resulting volumes, but
    faster.
    
    Author: Washington University School of Medicin
    
    Args:
        data_volume: the volume to smooth.
        label_volume: a label volume containing the parcels to smooth.
        kernel: the size of the gaussian smoothing kernel in mm, as sigma by\
            default.
        volume_out: the output volume.
        opt_fwhm: smoothing kernel size is FWHM, not sigma.
        opt_fix_zeros: treat zero values as not being data.
        opt_subvolume_subvol: select a single subvolume to smooth: the\
            subvolume number or name.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeParcelSmoothingOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_PARCEL_SMOOTHING_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-parcel-smoothing")
    cargs.append(execution.input_file(data_volume))
    cargs.append(execution.input_file(label_volume))
    cargs.append(str(kernel))
    cargs.append(volume_out)
    if opt_fwhm:
        cargs.append("-fwhm")
    if opt_fix_zeros:
        cargs.append("-fix-zeros")
    if opt_subvolume_subvol is not None:
        cargs.extend([
            "-subvolume",
            opt_subvolume_subvol
        ])
    ret = VolumeParcelSmoothingOutputs(
        root=execution.output_file("."),
        volume_out=execution.output_file(volume_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VOLUME_PARCEL_SMOOTHING_METADATA",
    "VolumeParcelSmoothingOutputs",
    "volume_parcel_smoothing",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FDRVAL_METADATA = Metadata(
    id="d7b752bd6acda76625f2e0880f59f3c2a7a453be.boutiques",
    name="fdrval",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class FdrvalOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fdrval(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """Computed q-values or p-values for the given thresholds"""


def fdrval(
    dset: InputPathType,
    sub: float,
    val_list: list[float],
    runner: Runner | None = None,
) -> FdrvalOutputs:
    """
    Computes q-values from FDR curve data stored in dataset headers.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/fdrval.html
    
    Args:
        dset: Input dataset.
        sub: Sub-brick number.
        val_list: List of threshold values.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FdrvalOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FDRVAL_METADATA)
    cargs = []
    cargs.append("fdrval")
    cargs.append("[OPTIONS]")
    cargs.append(execution.input_file(dset))
    cargs.append(str(sub))
    cargs.extend(map(str, val_list))
    ret = FdrvalOutputs(
        root=execution.output_file("."),
        output=execution.output_file("stdout.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FDRVAL_METADATA",
    "FdrvalOutputs",
    "fdrval",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

NEURO_DECONVOLVE_PY_METADATA = Metadata(
    id="ea023431386088245b3e959a0753d9b2581057ac.boutiques",
    name="neuro_deconvolve.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class NeuroDeconvolvePyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `neuro_deconvolve_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_head: OutputPathType
    """Main default output head file"""
    output_brik: OutputPathType
    """Main default output BRIK file"""
    kernel_file_out: OutputPathType | None
    """File storing the response kernel"""


def neuro_deconvolve_py(
    input_file: InputPathType,
    prefix: str,
    script: str,
    kernel: str | None = None,
    kernel_file: str | None = None,
    mask_dset: InputPathType | None = None,
    old_style: bool = False,
    tr: float | None = None,
    tr_nup: float | None = None,
    verbosity: float | None = None,
    runner: Runner | None = None,
) -> NeuroDeconvolvePyOutputs:
    """
    Generate a script to apply 3dTfitter to deconvolve an MRI signal (BOLD response
    curve) into a neuro response curve.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/neuro_deconvolve.py.html
    
    Args:
        input_file: Set the data to deconvolve.
        prefix: Set the prefix for output filenames.
        script: Specify the name of the output script.
        kernel: Set the response kernel.
        kernel_file: Set the filename to store the kernel in; should be at the\
            upsampled TR.
        mask_dset: Set a mask dataset for 3dTfitter to use.
        old_style: Make old-style script (pre-2015.02.24) for 1D case.
        tr: Set the scanner TR; needed for 1D formatted input files.
        tr_nup: Upsample factor for TR; number of pieces each original TR is\
            divided into.
        verbosity: Set the verbose level.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `NeuroDeconvolvePyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(NEURO_DECONVOLVE_PY_METADATA)
    cargs = []
    cargs.append("neuro_deconvolve.py")
    cargs.append(execution.input_file(input_file))
    cargs.append(prefix)
    cargs.append(script)
    if kernel is not None:
        cargs.extend([
            "-kernel",
            kernel
        ])
    if kernel_file is not None:
        cargs.extend([
            "-kernel_file",
            kernel_file
        ])
    if mask_dset is not None:
        cargs.extend([
            "-mask_dset",
            execution.input_file(mask_dset)
        ])
    if old_style:
        cargs.append("-old")
    if tr is not None:
        cargs.extend([
            "-tr",
            str(tr)
        ])
    if tr_nup is not None:
        cargs.extend([
            "-tr_nup",
            str(tr_nup)
        ])
    if verbosity is not None:
        cargs.extend([
            "-verb",
            str(verbosity)
        ])
    ret = NeuroDeconvolvePyOutputs(
        root=execution.output_file("."),
        output_head=execution.output_file(prefix + "+orig.HEAD"),
        output_brik=execution.output_file(prefix + "+orig.BRIK"),
        kernel_file_out=execution.output_file(kernel_file) if (kernel_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "NEURO_DECONVOLVE_PY_METADATA",
    "NeuroDeconvolvePyOutputs",
    "neuro_deconvolve_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_5TT2GMWMI_METADATA = Metadata(
    id="5e6be0e8d2d77946c8326a477cc65c226f37e2c4.boutiques",
    name="5tt2gmwmi",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class V5tt2gmwmiConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class V5tt2gmwmiOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_5tt2gmwmi(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    mask_out: OutputPathType
    """the output mask image"""


def v_5tt2gmwmi(
    v_5tt_in: InputPathType,
    mask_out: str,
    mask_in: InputPathType | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[V5tt2gmwmiConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> V5tt2gmwmiOutputs:
    """
    Generate a mask image appropriate for seeding streamlines on the grey
    matter-white matter interface.
    
    
    
    References:
    
    Smith, R. E.; Tournier, J.-D.; Calamante, F. & Connelly, A.
    Anatomically-constrained tractography:Improved diffusion MRI streamlines
    tractography through effective use of anatomical information. NeuroImage,
    2012, 62, 1924-1938.
    
    Author: Robert E. Smith (robert.smith@florey.edu.au)
    
    URL:
    https://mrtrix.readthedocs.io/en/latest/reference/commands/5tt2gmwmi.html
    
    Args:
        v_5tt_in: the input 5TT segmented anatomical image.
        mask_out: the output mask image.
        mask_in: Filter an input mask image according to those voxels that lie\
            upon the grey matter - white matter boundary. If no input mask is\
            provided, the output will be a whole-brain mask image calculated using\
            the anatomical image only.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V5tt2gmwmiOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_5TT2GMWMI_METADATA)
    cargs = []
    cargs.append("5tt2gmwmi")
    if mask_in is not None:
        cargs.extend([
            "-mask_in",
            execution.input_file(mask_in)
        ])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(execution.input_file(v_5tt_in))
    cargs.append(mask_out)
    ret = V5tt2gmwmiOutputs(
        root=execution.output_file("."),
        mask_out=execution.output_file(mask_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V5tt2gmwmiConfig",
    "V5tt2gmwmiOutputs",
    "V_5TT2GMWMI_METADATA",
    "v_5tt2gmwmi",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_WINSOR_METADATA = Metadata(
    id="14eef9e3bbd704e0f76d5d49b3f5be8c610834d1.boutiques",
    name="3dWinsor",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dWinsorOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_winsor(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile_head: OutputPathType | None
    """Output dataset with Winsorizing filter applied."""
    outfile_brik: OutputPathType | None
    """Output dataset with Winsorizing filter applied."""


def v_3d_winsor(
    dataset: InputPathType,
    irad: float | None = None,
    cbot: float | None = None,
    ctop: float | None = None,
    nrep: float | None = None,
    keepzero: bool = False,
    clip: float | None = None,
    prefix: str | None = None,
    mask: InputPathType | None = None,
    runner: Runner | None = None,
) -> V3dWinsorOutputs:
    """
    Apply a 3D 'Winsorizing' filter to a short-valued dataset.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dWinsor.html
    
    Args:
        dataset: Input dataset to apply the filter on.
        irad: Include all points within 'distance' rr in the operation, where\
            distance is defined as sqrt(i*i+j*j+k*k), and (i,j,k) are voxel index\
            offsets.
        cbot: Set bottom clip index to bb.
        ctop: Set top clip index to tt.
        nrep: Repeat filter nn times. If nn < 0, means to repeat filter until\
            less than abs(n) voxels change.
        keepzero: Don't filter voxels that are zero.
        clip: Set voxels at or below 'xx' to zero.
        prefix: Use 'pp' as the prefix for the output dataset.
        mask: Use 'mmm' as a mask dataset - voxels NOT in the mask won't be\
            filtered.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dWinsorOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_WINSOR_METADATA)
    cargs = []
    cargs.append("3dWinsor")
    if irad is not None:
        cargs.extend([
            "-irad",
            str(irad)
        ])
    if cbot is not None:
        cargs.extend([
            "-cbot",
            str(cbot)
        ])
    if ctop is not None:
        cargs.extend([
            "-ctop",
            str(ctop)
        ])
    if nrep is not None:
        cargs.extend([
            "-nrep",
            str(nrep)
        ])
    if keepzero:
        cargs.append("-keepzero")
    if clip is not None:
        cargs.extend([
            "-clip",
            str(clip)
        ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    cargs.append(execution.input_file(dataset))
    ret = V3dWinsorOutputs(
        root=execution.output_file("."),
        outfile_head=execution.output_file(prefix + "+*.HEAD") if (prefix is not None) else None,
        outfile_brik=execution.output_file(prefix + "+*.BRIK") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dWinsorOutputs",
    "V_3D_WINSOR_METADATA",
    "v_3d_winsor",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CAT_MATVEC_METADATA = Metadata(
    id="4a0fc2ef1f9e373552cdbe62d1a6bf70fa5b3987.boutiques",
    name="cat_matvec",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class CatMatvecOutputs(typing.NamedTuple):
    """
    Output object returned when calling `cat_matvec(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def cat_matvec(
    matvec_spec: list[str],
    four_by_four_format: bool = False,
    runner: Runner | None = None,
) -> CatMatvecOutputs:
    """
    Catenates 3D rotation+shift matrix+vector transformations.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/cat_matvec.html
    
    Args:
        matvec_spec: Specifies the matrix transformation. Can take forms\
            described in the documentation.
        four_by_four_format: Output matrix in augmented form (last row is 0 0 0\
            1). This option does not work with -MATRIX or -ONELINE.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CatMatvecOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CAT_MATVEC_METADATA)
    cargs = []
    cargs.append("cat_matvec")
    if four_by_four_format:
        cargs.append("-4x4")
    cargs.extend(matvec_spec)
    ret = CatMatvecOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CAT_MATVEC_METADATA",
    "CatMatvecOutputs",
    "cat_matvec",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DEDGE3_METADATA = Metadata(
    id="9db60bfb5c26a62877afdc35578a2c2b8a065792.boutiques",
    name="3dedge3",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dedge3Outputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dedge3(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType | None
    """Output dataset"""


def v_3dedge3(
    input_file: InputPathType,
    prefix: str | None = None,
    datum: str | None = None,
    scale_floats: float | None = None,
    runner: Runner | None = None,
) -> V3dedge3Outputs:
    """
    Does 3D Edge detection using the library 3DEdge.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dedge3.html
    
    Args:
        input_file: Input dataset.
        prefix: Sets the prefix of the output dataset.
        datum: Sets the datum of the output dataset.
        scale_floats: Multiply input by VAL, but only if the input datum is\
            float.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dedge3Outputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DEDGE3_METADATA)
    cargs = []
    cargs.append("3dedge3")
    cargs.extend([
        "-input",
        execution.input_file(input_file)
    ])
    cargs.append("[VERBOSE_FLAG]")
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if datum is not None:
        cargs.extend([
            "-datum",
            datum
        ])
    cargs.append("[FSCALE_FLAG]")
    cargs.append("[GSCALE_FLAG]")
    cargs.append("[NSCALE_FLAG]")
    if scale_floats is not None:
        cargs.extend([
            "-scale_floats",
            str(scale_floats)
        ])
    cargs.append("[AUTOMASK_FLAG]")
    ret = V3dedge3Outputs(
        root=execution.output_file("."),
        output_file=execution.output_file(prefix + ".nii.gz") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dedge3Outputs",
    "V_3DEDGE3_METADATA",
    "v_3dedge3",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FEAT_GM_PREPARE_METADATA = Metadata(
    id="69f99581f8df035a15b8bd30c71217642ca4c191.boutiques",
    name="feat_gm_prepare",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FeatGmPrepareOutputs(typing.NamedTuple):
    """
    Output object returned when calling `feat_gm_prepare(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def feat_gm_prepare(
    gm_output: str,
    feat_dirs_list: list[InputPathType],
    runner: Runner | None = None,
) -> FeatGmPrepareOutputs:
    """
    Prepare 4D grey matter files for higher-level analysis in FEAT.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FEAT
    
    Args:
        gm_output: 4D grey matter output file.
        feat_dirs_list: List of first-level FEAT output directories.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FeatGmPrepareOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FEAT_GM_PREPARE_METADATA)
    cargs = []
    cargs.append("feat_gm_prepare")
    cargs.append(gm_output)
    cargs.extend([execution.input_file(f) for f in feat_dirs_list])
    ret = FeatGmPrepareOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FEAT_GM_PREPARE_METADATA",
    "FeatGmPrepareOutputs",
    "feat_gm_prepare",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DMERGE_METADATA = Metadata(
    id="5e134d12632bbad5de1440df1dc412be8fda7b4f.boutiques",
    name="3dmerge",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dmergeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dmerge(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dataset: OutputPathType
    """Output dataset file"""


def v_3dmerge(
    input_files: list[InputPathType],
    output_file: str,
    runner: Runner | None = None,
) -> V3dmergeOutputs:
    """
    3dmerge edits and merges 3D datasets by applying various operations like
    thresholding, blurring, clustering, and more.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dmerge.html
    
    Args:
        input_files: Input dataset files.
        output_file: Output dataset prefix.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dmergeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DMERGE_METADATA)
    cargs = []
    cargs.append("3dmerge")
    cargs.extend([execution.input_file(f) for f in input_files])
    cargs.append("[EDITING_OPTIONS]")
    cargs.append("[MERGING_OPTIONS]")
    cargs.append("-prefix")
    cargs.extend([
        "-prefix",
        output_file
    ])
    ret = V3dmergeOutputs(
        root=execution.output_file("."),
        output_dataset=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dmergeOutputs",
    "V_3DMERGE_METADATA",
    "v_3dmerge",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

LESION_FILLING_METADATA = Metadata(
    id="78bb5280744f758c0c0f77125c36ae42ccd208cb.boutiques",
    name="lesion_filling",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class LesionFillingOutputs(typing.NamedTuple):
    """
    Output object returned when calling `lesion_filling(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType
    """Lesion filled output image"""


def lesion_filling(
    infile: InputPathType,
    outfile: str,
    lesionmask: InputPathType,
    wmmask: InputPathType | None = None,
    verbose_flag: bool = False,
    components_flag: bool = False,
    runner: Runner | None = None,
) -> LesionFillingOutputs:
    """
    Lesion filling tool as part of FSL.
    
    Author: University of Oxford (Mark Jenkinson & Taylor Hanayik)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/LESION_FILLING
    
    Args:
        infile: Input image filename (e.g., T1w image).
        outfile: Output filename (lesion filled image).
        lesionmask: Filename of lesion mask image.
        wmmask: Filename of white matter mask image.
        verbose_flag: Switch on diagnostic messages.
        components_flag: Save all lesion components as volumes.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LesionFillingOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LESION_FILLING_METADATA)
    cargs = []
    cargs.append("lesion_filling")
    cargs.extend([
        "-i",
        execution.input_file(infile)
    ])
    cargs.extend([
        "-o",
        outfile
    ])
    cargs.extend([
        "-l",
        execution.input_file(lesionmask)
    ])
    if wmmask is not None:
        cargs.extend([
            "-w",
            execution.input_file(wmmask)
        ])
    if verbose_flag:
        cargs.append("-v")
    if components_flag:
        cargs.append("-c")
    ret = LesionFillingOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file(outfile),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "LESION_FILLING_METADATA",
    "LesionFillingOutputs",
    "lesion_filling",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLNVOLS_METADATA = Metadata(
    id="3a2d3f7f4ac51c2cdbc37faf865b81554d950f93.boutiques",
    name="fslnvols",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FslnvolsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslnvols(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fslnvols(
    infile: InputPathType,
    runner: Runner | None = None,
) -> FslnvolsOutputs:
    """
    Retrieve the number of volumes in a 4D NIfTI file.
    
    Author: FMRIB Centre, University of Oxford
    
    Args:
        infile: Input NIfTI file (e.g., fmri.nii.gz).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslnvolsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLNVOLS_METADATA)
    cargs = []
    cargs.append("fslnvols")
    cargs.append(execution.input_file(infile))
    ret = FslnvolsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLNVOLS_METADATA",
    "FslnvolsOutputs",
    "fslnvols",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__MEASURE_IN2OUT_METADATA = Metadata(
    id="e686c3d1def3136323009906869a206046303967.boutiques",
    name="@measure_in2out",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VMeasureIn2outOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__measure_in2out(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    inout_dist: OutputPathType
    """Volumetric thickness/distance from in to out"""
    in_and_out: OutputPathType
    """Volumetric distance to inside and outside in 2 volumes"""
    inout_thick: OutputPathType
    """Unsmoothed thickness mapped to surface nodes"""
    inout_thick_smooth: OutputPathType
    """Smoothed thickness mapped to surface nodes"""
    maskset_output: OutputPathType
    """Mask file"""
    maskset_rs: OutputPathType
    """Resampled mask file"""
    anat_gii: OutputPathType
    """Surface representation of mask volume"""
    quick_spec: OutputPathType
    """Simple specification file for surface to use with suma commands"""


def v__measure_in2out(
    maskset: InputPathType,
    surfset: InputPathType,
    outdir: str,
    resample: str | None = None,
    increment: float | None = None,
    surfsmooth: float | None = None,
    maxthick: float | None = None,
    depthsearch: float | None = None,
    maskinoutvals: list[float] | None = None,
    keep_temp_files: bool = False,
    surfsmooth_method: str | None = None,
    fs_cort_dir: str | None = None,
    runner: Runner | None = None,
) -> VMeasureIn2outOutputs:
    """
    Compute thickness of mask using in2out method.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@measure_in2out.html
    
    Args:
        maskset: Mask dataset for input.
        surfset: Surface dataset onto which to map thickness (probably a\
            pial/gray matter surface).
        outdir: Output directory. If not specified, in2out_thickdir is used.
        resample: Resample input to mm in millimeters (put a number here). Set\
            this to half a voxel or "auto". No resampling is done by default.\
            Resampling is highly recommended for most 1mm data.
        increment: Test thickness at increments of sub-voxel distance. Default\
            is 1/4 voxel minimum distance (in-plane).
        surfsmooth: Smooth surface map of thickness by mm millimeters. Default\
            is 6 mm.
        maxthick: Search for maximum thickness value of mm millimeters. Default\
            is 6 mm.
        depthsearch: Map to surface by looking for max along mm millimeter\
            normal vectors. Default is 3 mm.
        maskinoutvals: Use v1 for value of mask, v2 and v3 for inside and\
            outside mask values (e.g., '1 -2 -1').
        keep_temp_files: Do not delete the intermediate files (for testing).
        surfsmooth_method: Heat method used for smoothing surfaces. Default is\
            HEAT_07 but HEAT_05 is also useful for some models.
        fs_cort_dir: Use FreeSurfer SUMA directory from @SUMA_Make_Spec_FS for\
            processing.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VMeasureIn2outOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__MEASURE_IN2OUT_METADATA)
    cargs = []
    cargs.append("@measure_in2out")
    cargs.append("-maskset")
    cargs.append(execution.input_file(maskset))
    cargs.append("-surfset")
    cargs.append(execution.input_file(surfset))
    cargs.append("-outdir")
    cargs.append(outdir)
    if resample is not None:
        cargs.extend([
            "-resample",
            resample
        ])
    if increment is not None:
        cargs.extend([
            "-increment",
            str(increment)
        ])
    if surfsmooth is not None:
        cargs.extend([
            "-surfsmooth",
            str(surfsmooth)
        ])
    if maxthick is not None:
        cargs.extend([
            "-maxthick",
            str(maxthick)
        ])
    if depthsearch is not None:
        cargs.extend([
            "-depthsearch",
            str(depthsearch)
        ])
    if maskinoutvals is not None:
        cargs.extend([
            "-maskinoutvals",
            *map(str, maskinoutvals)
        ])
    if keep_temp_files:
        cargs.append("-keep_temp_files")
    if surfsmooth_method is not None:
        cargs.extend([
            "-surfsmooth_method",
            surfsmooth_method
        ])
    if fs_cort_dir is not None:
        cargs.extend([
            "-fs_cort_dir",
            fs_cort_dir
        ])
    ret = VMeasureIn2outOutputs(
        root=execution.output_file("."),
        inout_dist=execution.output_file("inout_dist.nii.gz"),
        in_and_out=execution.output_file("in_and_out.nii.gz"),
        inout_thick=execution.output_file("inout_thick.niml.dset"),
        inout_thick_smooth=execution.output_file("inout_thick_smooth.niml.dset"),
        maskset_output=execution.output_file("maskset.nii.gz"),
        maskset_rs=execution.output_file("maskset_rs.nii.gz"),
        anat_gii=execution.output_file("anat.gii"),
        quick_spec=execution.output_file("quick.spec"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VMeasureIn2outOutputs",
    "V__MEASURE_IN2OUT_METADATA",
    "v__measure_in2out",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_VEC_RGB_TO_HSL_METADATA = Metadata(
    id="9bd7d5be67d0b333dca8898a8d70c130d3545628.boutiques",
    name="3dVecRGB_to_HSL",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dVecRgbToHslOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_vec_rgb_to_hsl(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_hsl_dataset: OutputPathType
    """Output HSL dataset"""


def v_3d_vec_rgb_to_hsl(
    prefix: str,
    in_vec: InputPathType,
    mask: InputPathType | None = None,
    in_scal: InputPathType | None = None,
    runner: Runner | None = None,
) -> V3dVecRgbToHslOutputs:
    """
    Convert a 3-brick RGB (red, green, blue) data set to an HSL (hue, saturation,
    luminance) one.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dVecRGB_to_HSL.html
    
    Args:
        prefix: Output file name part.
        in_vec: Input RGB vector file of three bricks, presumably each having\
            values in the interval [0,1].
        mask: Whole brain mask within which to calculate things. Otherwise,\
            data should be masked already.
        in_scal: Scalar file (single brick) which will be appended to the\
            output file, mainly aimed at loading in an FA data set for tract volume\
            coloration.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dVecRgbToHslOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_VEC_RGB_TO_HSL_METADATA)
    cargs = []
    cargs.append("3dVecRGBtoHSL")
    cargs.extend([
        "-prefix",
        prefix
    ])
    cargs.extend([
        "-in_vec",
        execution.input_file(in_vec)
    ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if in_scal is not None:
        cargs.extend([
            "-in_scal",
            execution.input_file(in_scal)
        ])
    ret = V3dVecRgbToHslOutputs(
        root=execution.output_file("."),
        output_hsl_dataset=execution.output_file(prefix + "_HSL+*.HEAD"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dVecRgbToHslOutputs",
    "V_3D_VEC_RGB_TO_HSL_METADATA",
    "v_3d_vec_rgb_to_hsl",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__FROM_RAI_METADATA = Metadata(
    id="4c4541fb95f3a90a933837e752e6809ba6b027ac.boutiques",
    name="@FromRAI",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VFromRaiOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__from_rai(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__from_rai(
    rai_coordinates: list[float],
    orientation: str,
    runner: Runner | None = None,
) -> VFromRaiOutputs:
    """
    Changes the RAI coordinates to the specified orientation.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@FromRAI.html
    
    Args:
        rai_coordinates: RAI coordinates X, Y, and Z.
        orientation: Orientation format.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VFromRaiOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__FROM_RAI_METADATA)
    cargs = []
    cargs.append("@FromRAI")
    cargs.extend([
        "-xyz",
        *map(str, rai_coordinates)
    ])
    cargs.extend([
        "-or",
        orientation
    ])
    ret = VFromRaiOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VFromRaiOutputs",
    "V__FROM_RAI_METADATA",
    "v__from_rai",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__DJUNCT_SLICE_SPACE_METADATA = Metadata(
    id="887a29726cf9eb734174135e87b08da1b9b5138c.boutiques",
    name="@djunct_slice_space",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VDjunctSliceSpaceOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__djunct_slice_space(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__djunct_slice_space(
    inset: InputPathType,
    nwin: float,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> VDjunctSliceSpaceOutputs:
    """
    A tiny adjunct program for @chauffeur_afni to calculate how to evenly space a
    number of slices within each view plane of a dataset.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@djunct_slice_space.html
    
    Args:
        inset: Name of input dataset.
        nwin: Number of windows (i.e., slices) that you want across each view\
            plane.
        help_: See helpfile.
        version: See version number.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VDjunctSliceSpaceOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__DJUNCT_SLICE_SPACE_METADATA)
    cargs = []
    cargs.append("adjunct_slice_space")
    cargs.append(execution.input_file(inset))
    cargs.append(str(nwin))
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-ver")
    ret = VDjunctSliceSpaceOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VDjunctSliceSpaceOutputs",
    "V__DJUNCT_SLICE_SPACE_METADATA",
    "v__djunct_slice_space",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ADJUNCT_TORT_READ_DP_ALIGN_PY_METADATA = Metadata(
    id="952bb6ede0bdbf6912679c14141fc2b25d59c521.boutiques",
    name="adjunct_tort_read_dp_align.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class AdjunctTortReadDpAlignPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `adjunct_tort_read_dp_align_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType
    """Output '1D' file in AFNI format with translation and rotation
    parameters."""


def adjunct_tort_read_dp_align_py(
    input_file: InputPathType,
    output_file: InputPathType,
    runner: Runner | None = None,
) -> AdjunctTortReadDpAlignPyOutputs:
    """
    Extract the 3 translation (in mm) and 3 rotation (in deg) parameters estimated
    by TORTOISE's DIFF_PREP tool during DWI processing.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/adjunct_tort_read_dp_align.py.html
    
    Args:
        input_file: Input *_transformations.txt file output by TORTOISE's\
            DIFF_PREP.
        output_file: Output '1D' file in AFNI format. A text file with 6\
            columns representing translation and rotation parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AdjunctTortReadDpAlignPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ADJUNCT_TORT_READ_DP_ALIGN_PY_METADATA)
    cargs = []
    cargs.append("adjunct_tort_read_mot_transforms.py")
    cargs.append(execution.input_file(input_file))
    cargs.append(execution.input_file(output_file))
    ret = AdjunctTortReadDpAlignPyOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file(pathlib.Path(output_file).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ADJUNCT_TORT_READ_DP_ALIGN_PY_METADATA",
    "AdjunctTortReadDpAlignPyOutputs",
    "adjunct_tort_read_dp_align_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

WARP2METRIC_METADATA = Metadata(
    id="2fd5850bcb7f32a9c9c10cc3635b0b1b82152cda.boutiques",
    name="warp2metric",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class Warp2metricFc:
    """
    use an input template fixel image to define fibre orientations and output a
    fixel image describing the change in fibre cross-section (FC) in the
    perpendicular plane to the fixel orientation. e.g. warp2metric warp.mif -fc
    fixel_template_directory output_fixel_directory fc.mif.
    """
    template_fixel_directory: InputPathType
    """use an input template fixel image to define fibre orientations and output
    a fixel image describing the change in fibre cross-section (FC) in the
    perpendicular plane to the fixel orientation. e.g. warp2metric warp.mif -fc
    fixel_template_directory output_fixel_directory fc.mif"""
    output_fixel_directory: str
    """use an input template fixel image to define fibre orientations and output
    a fixel image describing the change in fibre cross-section (FC) in the
    perpendicular plane to the fixel orientation. e.g. warp2metric warp.mif -fc
    fixel_template_directory output_fixel_directory fc.mif"""
    output_fixel_data: str
    """use an input template fixel image to define fibre orientations and output
    a fixel image describing the change in fibre cross-section (FC) in the
    perpendicular plane to the fixel orientation. e.g. warp2metric warp.mif -fc
    fixel_template_directory output_fixel_directory fc.mif"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-fc")
        cargs.append(execution.input_file(self.template_fixel_directory))
        cargs.append(self.output_fixel_directory)
        cargs.append(self.output_fixel_data)
        return cargs


@dataclasses.dataclass
class Warp2metricConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class Warp2metricOutputs(typing.NamedTuple):
    """
    Output object returned when calling `warp2metric(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    jmat: OutputPathType | None
    """output a Jacobian matrix image stored in column-major order along the 4th
    dimension.Note the output jacobian describes the warp gradient w.r.t the
    scanner space coordinate system """
    jdet: OutputPathType | None
    """output the Jacobian determinant instead of the full matrix """


def warp2metric(
    in_: InputPathType,
    fc: Warp2metricFc | None = None,
    jmat: str | None = None,
    jdet: str | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[Warp2metricConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> Warp2metricOutputs:
    """
    Compute fixel-wise or voxel-wise metrics from a 4D deformation field.
    
    
    
    References:
    
    Raffelt, D.; Tournier, JD/; Smith, RE.; Vaughan, DN.; Jackson, G.; Ridgway,
    GR. Connelly, A.Investigating White Matter Fibre Density and Morphology
    using Fixel-Based Analysis. Neuroimage, 2017, 144, 58-73, doi:
    10.1016/j.neuroimage.2016.09.029.
    
    Author: David Raffelt (david.raffelt@florey.edu.au)
    
    URL:
    https://mrtrix.readthedocs.io/en/latest/reference/commands/warp2metric.html
    
    Args:
        in_: the input deformation field.
        fc: use an input template fixel image to define fibre orientations and\
            output a fixel image describing the change in fibre cross-section (FC)\
            in the perpendicular plane to the fixel orientation. e.g. warp2metric\
            warp.mif -fc fixel_template_directory output_fixel_directory fc.mif.
        jmat: output a Jacobian matrix image stored in column-major order along\
            the 4th dimension.Note the output jacobian describes the warp gradient\
            w.r.t the scanner space coordinate system.
        jdet: output the Jacobian determinant instead of the full matrix.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Warp2metricOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(WARP2METRIC_METADATA)
    cargs = []
    cargs.append("warp2metric")
    if fc is not None:
        cargs.extend(fc.run(execution))
    if jmat is not None:
        cargs.extend([
            "-jmat",
            jmat
        ])
    if jdet is not None:
        cargs.extend([
            "-jdet",
            jdet
        ])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(execution.input_file(in_))
    ret = Warp2metricOutputs(
        root=execution.output_file("."),
        jmat=execution.output_file(jmat) if (jmat is not None) else None,
        jdet=execution.output_file(jdet) if (jdet is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "WARP2METRIC_METADATA",
    "Warp2metricConfig",
    "Warp2metricFc",
    "Warp2metricOutputs",
    "warp2metric",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_INV_FMRI_METADATA = Metadata(
    id="cb27e0de727e2a1295bb09c0a66d6ab3481186c2.boutiques",
    name="3dInvFMRI",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dInvFmriOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_inv_fmri(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType | None
    """The output 1D file."""


def v_3d_inv_fmri(
    input_file: InputPathType,
    activation_map: InputPathType,
    map_weight: InputPathType | None = None,
    mask: InputPathType | None = None,
    baseline_file: list[InputPathType] | None = None,
    polynom_order: float | None = None,
    output_file: str | None = None,
    method: str | None = None,
    alpha: float | None = None,
    smooth_fir: bool = False,
    smooth_median: bool = False,
    runner: Runner | None = None,
) -> V3dInvFmriOutputs:
    """
    Program to compute stimulus time series, given a 3D+time dataset and an
    activation map (the inverse of the usual FMRI analysis problem).
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dInvFMRI.html
    
    Args:
        input_file: Input 3D+time dataset.
        activation_map: Defines activation map; should be a bucket dataset\
            where each sub-brick defines the beta weight map for an unknown\
            stimulus time series.
        map_weight: Defines a weighting factor for the map. Dataset can have\
            either 1 sub-brick or the same number as in the -map dataset.
        mask: Defines a mask dataset to restrict input voxels from -data and\
            -map.
        baseline_file: Baseline time series file. Each column of the file\
            defines a baseline time series.
        polynom_order: Adds polynomials of specified order to the baseline\
            collection.
        output_file: Name of the 1D output file.
        method: Determines the method to use: C for least squares fit to data\
            matrix (default) or K for least squares fit to activation matrix.
        alpha: Set the alpha factor to penalize large values of the output\
            vectors.
        smooth_fir: Smooth the results with a 5 point lowpass FIR filter.
        smooth_median: Smooth the results with a 5 point median filter.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dInvFmriOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_INV_FMRI_METADATA)
    cargs = []
    cargs.append("3dInvFMRI")
    cargs.extend([
        "-data",
        execution.input_file(input_file)
    ])
    cargs.extend([
        "-map",
        execution.input_file(activation_map)
    ])
    if map_weight is not None:
        cargs.extend([
            "-mapwt",
            execution.input_file(map_weight)
        ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if baseline_file is not None:
        cargs.extend([
            "-base",
            *[execution.input_file(f) for f in baseline_file]
        ])
    if polynom_order is not None:
        cargs.extend([
            "-polort",
            str(polynom_order)
        ])
    if output_file is not None:
        cargs.extend([
            "-out",
            output_file
        ])
    if method is not None:
        cargs.extend([
            "-method",
            method
        ])
    if alpha is not None:
        cargs.extend([
            "-alpha",
            str(alpha)
        ])
    if smooth_fir:
        cargs.append("-fir5")
    if smooth_median:
        cargs.append("-median5")
    ret = V3dInvFmriOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file(output_file) if (output_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dInvFmriOutputs",
    "V_3D_INV_FMRI_METADATA",
    "v_3d_inv_fmri",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FAT_MVM_PREP_PY_METADATA = Metadata(
    id="3815f6c885d1532f06123e9f01ad665a3388567f.boutiques",
    name="fat_mvm_prep.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class FatMvmPrepPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fat_mvm_prep_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    mvmtbl: OutputPathType
    """Output tabular text file for 3dMVM."""
    mvmprep_log: OutputPathType
    """Log file detailing subject matching and ROI list."""


def fat_mvm_prep_py(
    prefix: str,
    csv_file: InputPathType,
    runner: Runner | None = None,
) -> FatMvmPrepPyOutputs:
    """
    Combine FATCAT output with CSV data for statistical modeling.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/fat_mvm_prep.py.html
    
    Args:
        prefix: Prefix for output files.
        csv_file: Comma-separated variable (CSV) file for input.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FatMvmPrepPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FAT_MVM_PREP_PY_METADATA)
    cargs = []
    cargs.append("fat_mvm_prep.py")
    cargs.append("-p")
    cargs.extend([
        "-p",
        prefix
    ])
    cargs.append("-c")
    cargs.extend([
        "-c",
        execution.input_file(csv_file)
    ])
    cargs.append("[MATRIX_OPTION]")
    ret = FatMvmPrepPyOutputs(
        root=execution.output_file("."),
        mvmtbl=execution.output_file(prefix + "_MVMtbl.txt"),
        mvmprep_log=execution.output_file(prefix + "_MVMprep.log"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FAT_MVM_PREP_PY_METADATA",
    "FatMvmPrepPyOutputs",
    "fat_mvm_prep_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DMATCALC_METADATA = Metadata(
    id="005be9a1c54f172b8c36597f9d1993ea3ec79c14.boutiques",
    name="3dmatcalc",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dmatcalcOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dmatcalc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_header: OutputPathType
    """Output dataset header file."""
    output_brick: OutputPathType
    """Output dataset brick file."""


def v_3dmatcalc(
    input_dataset: InputPathType,
    input_matrix: InputPathType,
    output_dataset: str,
    mask: InputPathType | None = None,
    runner: Runner | None = None,
) -> V3dmatcalcOutputs:
    """
    Apply a matrix to a dataset, voxel-by-voxel, to produce a new dataset.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dmatcalc.html
    
    Args:
        input_dataset: Input dataset to be processed.
        input_matrix: The matrix to be applied, specified as a .1D file or as\
            an expression in the syntax of 1dmatcalc.
        output_dataset: Prefix for the output dataset.
        mask: Apply the matrix only to voxels in the mask; other voxels will be\
            set to all zeroes.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dmatcalcOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DMATCALC_METADATA)
    cargs = []
    cargs.append("3dmatcalc")
    cargs.append("-input")
    cargs.append(execution.input_file(input_dataset))
    cargs.append("-matrix")
    cargs.append(execution.input_file(input_matrix))
    cargs.append("-prefix")
    cargs.append(output_dataset)
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    ret = V3dmatcalcOutputs(
        root=execution.output_file("."),
        output_header=execution.output_file(output_dataset + "+tlrc.HEAD"),
        output_brick=execution.output_file(output_dataset + "+tlrc.BRIK"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dmatcalcOutputs",
    "V_3DMATCALC_METADATA",
    "v_3dmatcalc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLPSPEC_METADATA = Metadata(
    id="034df51dc010372ef67f2310d915e1175d89e8c6.boutiques",
    name="fslpspec",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FslpspecOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslpspec(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_pspec: OutputPathType | None
    """Output power spectrum image"""


def fslpspec(
    infile: InputPathType,
    outfile: str | None = None,
    runner: Runner | None = None,
) -> FslpspecOutputs:
    """
    Estimate the power spectrum of 4D fMRI time series data.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FSL
    
    Args:
        infile: Input 4D fMRI time series image (e.g. fMRI_data.nii.gz).
        outfile: Output power spectrum image (e.g. pspec_data.nii.gz).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslpspecOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLPSPEC_METADATA)
    cargs = []
    cargs.append("fslpspec")
    cargs.append(execution.input_file(infile))
    if outfile is not None:
        cargs.append(outfile)
    cargs.append("[OPTIONS]")
    ret = FslpspecOutputs(
        root=execution.output_file("."),
        output_pspec=execution.output_file(outfile) if (outfile is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLPSPEC_METADATA",
    "FslpspecOutputs",
    "fslpspec",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SLICES_SUMMARY_METADATA = Metadata(
    id="bcfb859e6121ad5b718e68a1d1cc66158c82e918.boutiques",
    name="slices_summary",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class SlicesSummaryOutputs(typing.NamedTuple):
    """
    Output object returned when calling `slices_summary(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    summary_images_directory: OutputPathType
    """Directory containing summary images"""
    combined_summary_image: OutputPathType
    """Combined summary PNG image"""


def slices_summary(
    v_4d_input_file: InputPathType,
    threshold: float,
    background_image: InputPathType,
    pictures_sum_second: str,
    pictures_sum_second_: str,
    output_png: str,
    timepoints: str,
    single_slice_flag: bool = False,
    darker_background_flag: bool = False,
    dumb_rule_flag: bool = False,
    runner: Runner | None = None,
) -> SlicesSummaryOutputs:
    """
    Generate summary PNG images for 4D neuroimaging data.
    
    Args:
        v_4d_input_file: 4D input image (e.g., melodic_IC).
        threshold: Threshold value for the slices.
        background_image: Background image file (e.g., standard/MNI152_T1_2mm).
        pictures_sum_second: Path to summary images directory.
        pictures_sum_second_: Path to summary images directory.
        output_png: Output PNG file.
        timepoints: Space-separated list of timepoints to use; first timepoint\
            is 0.
        single_slice_flag: Generate single-slice summary images instead of\
            3-slice.
        darker_background_flag: Make background darker and colour brighter, for\
            greater colour visibility.
        dumb_rule_flag: Use dumber rule for choosing optimal slice.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SlicesSummaryOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SLICES_SUMMARY_METADATA)
    cargs = []
    cargs.append("slices_summary")
    cargs.append(execution.input_file(v_4d_input_file))
    cargs.append(str(threshold))
    cargs.append(execution.input_file(background_image))
    cargs.append(pictures_sum_second)
    if single_slice_flag:
        cargs.append("-1")
    if darker_background_flag:
        cargs.append("-d")
    if dumb_rule_flag:
        cargs.append("-c")
    cargs.append("|")
    cargs.append("slices_summary")
    cargs.append(pictures_sum_second_)
    cargs.append(output_png)
    cargs.append(timepoints)
    ret = SlicesSummaryOutputs(
        root=execution.output_file("."),
        summary_images_directory=execution.output_file(pictures_sum_second_),
        combined_summary_image=execution.output_file(output_png),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SLICES_SUMMARY_METADATA",
    "SlicesSummaryOutputs",
    "slices_summary",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CONVERT_MATRIX4_TO_MATRIX2_METADATA = Metadata(
    id="ff3f9f755a9674f89a4af46ef4df75239803f74f.boutiques",
    name="convert-matrix4-to-matrix2",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class ConvertMatrix4ToMatrix2IndividualFibersOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ConvertMatrix4ToMatrix2IndividualFibers | None(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    fiber_1: OutputPathType
    """output file for first fiber"""
    fiber_2: OutputPathType
    """output file for second fiber"""
    fiber_3: OutputPathType
    """output file for third fiber"""


@dataclasses.dataclass
class ConvertMatrix4ToMatrix2IndividualFibers:
    """
    output files for each fiber direction.
    """
    fiber_1: str
    """output file for first fiber"""
    fiber_2: str
    """output file for second fiber"""
    fiber_3: str
    """output file for third fiber"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-individual-fibers")
        cargs.append(self.fiber_1)
        cargs.append(self.fiber_2)
        cargs.append(self.fiber_3)
        return cargs
    
    def outputs(
        self,
        execution: Execution,
    ) -> ConvertMatrix4ToMatrix2IndividualFibersOutputs:
        """
        Collect output file paths.
        
        Args:
            execution: The execution object.
        Returns:
            NamedTuple of outputs (described in `ConvertMatrix4ToMatrix2IndividualFibersOutputs`).
        """
        ret = ConvertMatrix4ToMatrix2IndividualFibersOutputs(
            root=execution.output_file("."),
            fiber_1=execution.output_file(self.fiber_1),
            fiber_2=execution.output_file(self.fiber_2),
            fiber_3=execution.output_file(self.fiber_3),
        )
        return ret


class ConvertMatrix4ToMatrix2Outputs(typing.NamedTuple):
    """
    Output object returned when calling `convert_matrix4_to_matrix2(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    counts_out: OutputPathType
    """the total fiber counts, as a cifti file"""
    distance_out: OutputPathType
    """the distances, as a cifti file"""
    individual_fibers: ConvertMatrix4ToMatrix2IndividualFibersOutputs | None
    """Outputs from `ConvertMatrix4ToMatrix2IndividualFibers`."""


def convert_matrix4_to_matrix2(
    matrix4_wbsparse: str,
    counts_out: str,
    distance_out: str,
    opt_distances: bool = False,
    individual_fibers: ConvertMatrix4ToMatrix2IndividualFibers | None = None,
    runner: Runner | None = None,
) -> ConvertMatrix4ToMatrix2Outputs:
    """
    Generates a matrix2 cifti from matrix4 wbsparse.
    
    This command makes a cifti file from the fiber counts in a matrix4 wbsparse
    file, and optionally a second cifti file from the distances. Note that while
    the total count is stored exactly, the per-fiber counts are stored as
    approximate fractions, so the output of -individual-fibers will contain
    nonintegers.
    
    Author: Washington University School of Medicin
    
    Args:
        matrix4_wbsparse: a wbsparse matrix4 file.
        counts_out: the total fiber counts, as a cifti file.
        distance_out: the distances, as a cifti file.
        opt_distances: output average trajectory distance.
        individual_fibers: output files for each fiber direction.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ConvertMatrix4ToMatrix2Outputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CONVERT_MATRIX4_TO_MATRIX2_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-convert-matrix4-to-matrix2")
    cargs.append(matrix4_wbsparse)
    cargs.append(counts_out)
    if opt_distances:
        cargs.append("-distances")
    cargs.append(distance_out)
    if individual_fibers is not None:
        cargs.extend(individual_fibers.run(execution))
    ret = ConvertMatrix4ToMatrix2Outputs(
        root=execution.output_file("."),
        counts_out=execution.output_file(counts_out),
        distance_out=execution.output_file(distance_out),
        individual_fibers=individual_fibers.outputs(execution) if individual_fibers else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CONVERT_MATRIX4_TO_MATRIX2_METADATA",
    "ConvertMatrix4ToMatrix2IndividualFibers",
    "ConvertMatrix4ToMatrix2IndividualFibersOutputs",
    "ConvertMatrix4ToMatrix2Outputs",
    "convert_matrix4_to_matrix2",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_TPROJECT_METADATA = Metadata(
    id="502ad8401b7fb078cc07321c449820baf4cd172b.boutiques",
    name="3dTproject",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dTprojectOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_tproject(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_file: OutputPathType
    """Output file."""


def v_3d_tproject(
    in_file: InputPathType,
    tr: float | None = None,
    automask: bool = False,
    bandpass: list[float] | None = None,
    blur: float | None = None,
    cenmode: typing.Literal["KILL", "ZERO", "NTRP"] | None = None,
    censor: InputPathType | None = None,
    censortr: list[str] | None = None,
    concat: InputPathType | None = None,
    dsort: list[InputPathType] | None = None,
    mask: InputPathType | None = None,
    noblock: bool = False,
    norm: bool = False,
    ort: InputPathType | None = None,
    polort: int | None = None,
    stopband: list[float] | None = None,
    runner: Runner | None = None,
) -> V3dTprojectOutputs:
    """
    This program projects (detrends) out various 'nuisance' time series from each
    voxel in the input dataset. Note that all the projections are done via linear
    regression, including the frequency-based options such as '-passband'. In this
    way, you can bandpass time-censored data, and at the same time, remove other
    time series of no interest (e.g., physiological estimates, motion parameters).
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dTproject.html
    
    Args:
        in_file: Input file to 3dtproject.
        tr: Use time step dd for the frequency calculations,rather than the\
            value stored in the dataset header.
        automask: Generate a mask automatically.
        bandpass: (a float, a float). Remove all frequencies except those in\
            the range.
        blur: Blur (inside the mask only) with a filter that haswidth (fwhm) of\
            fff millimeters.spatial blurring (if done) is after the timeseries\
            filtering.
        cenmode: 'kill' or 'zero' or 'ntrp'. Specifies how censored time points\
            are treated in the output dataset:* mode = zero -- put zero values in\
            their place; output dataset is same length as input* mode = kill --\
            remove those time points; output dataset is shorter than input* mode =\
            ntrp -- censored values are replaced by interpolated neighboring (in\
            time) non-censored values, before any projections, and then the\
            analysis proceeds without actual removal of any time points -- this\
            feature is to keep the spanish inquisition happy.* the default mode is\
            kill !!!.
        censor: Filename of censor .1d time series.this is a file of 1s and 0s,\
            indicating whichtime points are to be included (1) and which areto be\
            excluded (0).
        censortr: List of strings that specify time indexes to be removed from\
            the analysis. each string isof one of the following forms:* ``37`` =>\
            remove global time index #37* ``2:37`` => remove time index #37 in run\
            #2* ``37..47`` => remove global time indexes #37-47* ``37-47`` => same\
            as above* ``2:37..47`` => remove time indexes #37-47 in run #2*\
            ``*:0-2`` => remove time indexes #0-2 in all runs * time indexes within\
            each run start at 0. * run indexes start at 1 (just be to confusing). *\
            n.b.: 2:37,47 means index #37 in run #2 and global time index 47; it\
            does not mean index #37 in run #2 and index #47 in run #2.
        concat: The catenation file, as in 3ddeconvolve, containing thetr\
            indexes of the start points for each contiguous runwithin the input\
            dataset (the first entry should be 0).* also as in 3ddeconvolve, if the\
            input dataset is automatically catenated from a collection of datasets,\
            then the run start indexes are determined directly, and '-concat' is\
            not needed (and will be ignored).* each run must have at least 9 time\
            points after censoring, or the program will not work!* the only use\
            made of this input is in setting up the bandpass/stopband regressors.*\
            '-ort' and '-dsort' regressors run through all time points, as read in.\
            if you want separate projections in each run, then you must either\
            break these ort files into appropriate components, or you must run\
            3dtproject for each run separately, using the appropriate pieces from\
            the ort files via the ``{...}`` selector for the 1d files and the\
            ``[...]`` selector for the datasets.
        dsort: Remove the 3d+time time series in dataset fset.* that is, 'fset'\
            contains a different nuisance time series for each voxel (e.g., from\
            anaticor).* multiple -dsort options are allowed.
        mask: Only operate on voxels nonzero in the mset dataset.* voxels\
            outside the mask will be filled with zeros.* if no masking option is\
            given, then all voxels will be processed.
        noblock: Also as in 3ddeconvolve, if you want the program to treatan\
            auto-catenated dataset as one long run, use this option.however,\
            '-noblock' will not affect catenation if you usethe '-concat' option.
        norm: normalize each output time series to have sum ofsquares = 1. this\
            is the last operation.
        ort: Remove each column in file.each column will have its mean removed.
        polort: Remove polynomials up to and including degree pp.* default\
            value is 2.* it makes no sense to use a value of pp greater than 2, if\
            you are bandpassing out the lower frequencies!* for catenated datasets,\
            each run gets a separate set set of pp+1 legendre polynomial\
            regressors.* use of -polort -1 is not advised (if data mean != 0), even\
            if -ort contains constant terms, as all means are removed.
        stopband: (a float, a float). Remove all frequencies in the range.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dTprojectOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_TPROJECT_METADATA)
    cargs = []
    cargs.append("3dTproject")
    cargs.extend([
        "-input",
        execution.input_file(in_file)
    ])
    cargs.append("[OUT_FILE]")
    if tr is not None:
        cargs.extend([
            "-TR",
            str(tr)
        ])
    if automask:
        cargs.append("-automask")
    if bandpass is not None:
        cargs.extend([
            "-bandpass",
            *map(str, bandpass)
        ])
    if blur is not None:
        cargs.extend([
            "-blur",
            str(blur)
        ])
    if cenmode is not None:
        cargs.extend([
            "-cenmode",
            cenmode
        ])
    if censor is not None:
        cargs.extend([
            "-censor",
            execution.input_file(censor)
        ])
    if censortr is not None:
        cargs.extend([
            "-CENSORTR",
            *censortr
        ])
    if concat is not None:
        cargs.extend([
            "-concat",
            execution.input_file(concat)
        ])
    if dsort is not None:
        cargs.extend([
            "-dsort",
            *[execution.input_file(f) for f in dsort]
        ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if noblock:
        cargs.append("-noblock")
    if norm:
        cargs.append("-norm")
    if ort is not None:
        cargs.extend([
            "-ort",
            execution.input_file(ort)
        ])
    if polort is not None:
        cargs.extend([
            "-polort",
            str(polort)
        ])
    if stopband is not None:
        cargs.extend([
            "-stopband",
            *map(str, stopband)
        ])
    ret = V3dTprojectOutputs(
        root=execution.output_file("."),
        out_file=execution.output_file(pathlib.Path(in_file).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dTprojectOutputs",
    "V_3D_TPROJECT_METADATA",
    "v_3d_tproject",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURF_MEASURES_METADATA = Metadata(
    id="456801b092370c4bee5c9cdefbc1662333250216.boutiques",
    name="SurfMeasures",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class SurfMeasuresOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surf_measures(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_1_d: OutputPathType
    """Output in 1D format"""
    output_dset: OutputPathType
    """Output in specified dataset format"""


def surf_measures(
    runner: Runner | None = None,
) -> SurfMeasuresOutputs:
    """
    Compute measures from surface dataset(s).
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/SurfMeasures.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfMeasuresOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURF_MEASURES_METADATA)
    cargs = []
    cargs.append("SurfMeasures")
    cargs.append("[OPTIONS]")
    cargs.append("-spec")
    cargs.append("SPEC_FILE")
    cargs.append("-out")
    cargs.append("OUTFILE")
    ret = SurfMeasuresOutputs(
        root=execution.output_file("."),
        output_1_d=execution.output_file("[OUTFILE_1D].1D"),
        output_dset=execution.output_file("[OUTFILE]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURF_MEASURES_METADATA",
    "SurfMeasuresOutputs",
    "surf_measures",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FIXEL2PEAKS_METADATA = Metadata(
    id="98ed9c18cf276e5b938d70b66727959cf8643284.boutiques",
    name="fixel2peaks",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class Fixel2peaksConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class Fixel2peaksOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fixel2peaks(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out: OutputPathType
    """the output peaks image"""


def fixel2peaks(
    in_: str,
    out: str,
    number: int | None = None,
    nan: bool = False,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[Fixel2peaksConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> Fixel2peaksOutputs:
    """
    Convert data in the fixel directory format into a 4D image of 3-vectors.
    
    If a fixel data file is provided as input, then the 3-vectors in the output
    image will be scaled based on the data in that file. If the input is instead
    the fixel directory, or the index or directions file, then all output
    3-vectors will possess unit norm.
    
    References:
    
    .
    
    Author: Robert E. Smith (robert.smith@florey.edu.au)
    
    URL:
    https://mrtrix.readthedocs.io/en/latest/reference/commands/fixel2peaks.html
    
    Args:
        in_: the input fixel information.
        out: the output peaks image.
        number: maximum number of fixels in each voxel (default: based on input\
            data).
        nan: fill excess peak data with NaNs rather than zeroes.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Fixel2peaksOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FIXEL2PEAKS_METADATA)
    cargs = []
    cargs.append("fixel2peaks")
    if number is not None:
        cargs.extend([
            "-number",
            str(number)
        ])
    if nan:
        cargs.append("-nan")
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(in_)
    cargs.append(out)
    ret = Fixel2peaksOutputs(
        root=execution.output_file("."),
        out=execution.output_file(out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FIXEL2PEAKS_METADATA",
    "Fixel2peaksConfig",
    "Fixel2peaksOutputs",
    "fixel2peaks",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

PROMPT_POPUP_METADATA = Metadata(
    id="7518dc8a00d72b77b36f749f20f87fefe2a98560.boutiques",
    name="prompt_popup",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class PromptPopupOutputs(typing.NamedTuple):
    """
    Output object returned when calling `prompt_popup(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def prompt_popup(
    message_pause: str | None = None,
    buttons_b: list[str] | None = None,
    timeout_to: float | None = None,
    runner: Runner | None = None,
) -> PromptPopupOutputs:
    """
    A command-line tool that pops up a window prompting user interaction with a
    message and buttons.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/prompt_popup.html
    
    Args:
        message_pause: Same as -message to match the old prompt_user.
        buttons_b: Same as -button.
        timeout_to: Same as -timeout TT.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `PromptPopupOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(PROMPT_POPUP_METADATA)
    cargs = []
    cargs.append("prompt_popup")
    cargs.append("-message")
    if message_pause is not None:
        cargs.extend([
            "-pause",
            message_pause
        ])
    cargs.append("-button")
    if buttons_b is not None:
        cargs.extend([
            "-b",
            *buttons_b
        ])
    cargs.append("-timeout")
    if timeout_to is not None:
        cargs.extend([
            "-to",
            str(timeout_to)
        ])
    ret = PromptPopupOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "PROMPT_POPUP_METADATA",
    "PromptPopupOutputs",
    "prompt_popup",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ROI_METADATA = Metadata(
    id="0182836486efae1debe989da6ba98d23ed8c3872.boutiques",
    name="roi",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class RoiOutputs(typing.NamedTuple):
    """
    Output object returned when calling `roi(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    roi_file_outfile: OutputPathType
    """Output ROI file."""


def roi(
    in_file: InputPathType,
    roi_file: str,
    x_min: int | None = None,
    x_size: int | None = None,
    y_min: int | None = None,
    y_size: int | None = None,
    z_min: int | None = None,
    z_size: int | None = None,
    t_min: int | None = None,
    t_size: int | None = None,
    runner: Runner | None = None,
) -> RoiOutputs:
    """
    Extract region of interest (ROI) from an image.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/Fslutils
    
    Args:
        in_file: Input image to extract ROI from.
        roi_file: Output ROI file.
        x_min: Minimum index for x-dimension.
        x_size: Size of ROI for x-dimension.
        y_min: Minimum index for y-dimension.
        y_size: Size of ROI for y-dimension.
        z_min: Minimum index for z-dimension.
        z_size: Size of ROI for z-dimension.
        t_min: Minimum index for t-dimension.
        t_size: Size of ROI in t-dimension.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RoiOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ROI_METADATA)
    cargs = []
    cargs.append("fslroi")
    cargs.append(execution.input_file(in_file))
    cargs.append(roi_file)
    if x_min is not None:
        cargs.append(str(x_min))
    if x_size is not None:
        cargs.append(str(x_size))
    if y_min is not None:
        cargs.append(str(y_min))
    if y_size is not None:
        cargs.append(str(y_size))
    if z_min is not None:
        cargs.append(str(z_min))
    if z_size is not None:
        cargs.append(str(z_size))
    if t_min is not None:
        cargs.append(str(t_min))
    if t_size is not None:
        cargs.append(str(t_size))
    ret = RoiOutputs(
        root=execution.output_file("."),
        roi_file_outfile=execution.output_file(roi_file + ".nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ROI_METADATA",
    "RoiOutputs",
    "roi",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

APQC_MAKE_HTML_PY_METADATA = Metadata(
    id="1cc63e58e9b64d6635146ce733bef0bda4712a25.boutiques",
    name="apqc_make_html.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class ApqcMakeHtmlPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `apqc_make_html_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def apqc_make_html_py(
    qc_dir: str,
    runner: Runner | None = None,
) -> ApqcMakeHtmlPyOutputs:
    """
    Tool to generate HTML reports.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/apqc_make_html.py.html
    
    Args:
        qc_dir: Directory where QC files will be saved.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ApqcMakeHtmlPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(APQC_MAKE_HTML_PY_METADATA)
    cargs = []
    cargs.append("apqc_make_html.py")
    cargs.append("-qc_dir")
    cargs.append(qc_dir)
    ret = ApqcMakeHtmlPyOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "APQC_MAKE_HTML_PY_METADATA",
    "ApqcMakeHtmlPyOutputs",
    "apqc_make_html_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_2SWAP_METADATA = Metadata(
    id="1e62c85edeb2251274dcf751c3aac90766f7d061.boutiques",
    name="2swap",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V2swapOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_2swap(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_2swap(
    input_files: list[InputPathType],
    quiet: bool = False,
    runner: Runner | None = None,
) -> V2swapOutputs:
    """
    Swaps byte pairs on the files listed.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/2swap.html
    
    Args:
        input_files: Input files.
        quiet: Work quietly.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V2swapOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_2SWAP_METADATA)
    cargs = []
    cargs.append("2swap")
    if quiet:
        cargs.append("-q")
    cargs.extend([execution.input_file(f) for f in input_files])
    ret = V2swapOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V2swapOutputs",
    "V_2SWAP_METADATA",
    "v_2swap",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FLIRT_AVERAGE_METADATA = Metadata(
    id="62d2397bf5aa779cedf7bb8e4fa2e04058e106f8.boutiques",
    name="flirt_average",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FlirtAverageOutputs(typing.NamedTuple):
    """
    Output object returned when calling `flirt_average(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType
    """Averaged output image"""


def flirt_average(
    ninputs: int,
    input1: InputPathType,
    input2: InputPathType,
    output_file: str,
    reference_image: InputPathType | None = None,
    flirt_options: str | None = None,
    runner: Runner | None = None,
) -> FlirtAverageOutputs:
    """
    Averages multiple input images after linear registration (FLIRT).
    
    Author: FMRIB Analysis Group, Oxford Centre for Functional MRI of the Brain
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FLIRT
    
    Args:
        ninputs: Number of input images.
        input1: First input image (e.g. rawT1_1.nii.gz).
        input2: Second input image (e.g. rawT1_2.nii.gz).
        output_file: Output image (e.g. averageT1.nii.gz).
        reference_image: Reference image to use instead of first input.
        flirt_options: Options to be passed to FLIRT.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FlirtAverageOutputs`).
    """
    if not (2 <= ninputs): 
        raise ValueError(f"'ninputs' must be greater than 2 <= x but was {ninputs}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(FLIRT_AVERAGE_METADATA)
    cargs = []
    cargs.append("flirt_average")
    cargs.append(str(ninputs))
    cargs.append(execution.input_file(input1))
    cargs.append(execution.input_file(input2))
    cargs.append("...")
    cargs.append(output_file)
    if reference_image is not None:
        cargs.extend([
            "-FAref",
            execution.input_file(reference_image)
        ])
    if flirt_options is not None:
        cargs.append(flirt_options)
    ret = FlirtAverageOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file(output_file + ".nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FLIRT_AVERAGE_METADATA",
    "FlirtAverageOutputs",
    "flirt_average",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

REG_AVERAGE_METADATA = Metadata(
    id="1f7c3b11cba221df2cf597e36ec48fc51c2e4500.boutiques",
    name="reg_average",
    package="niftyreg",
    container_image_tag="vnmd/niftyreg_1.4.0:20220819",
)


class RegAverageOutputs(typing.NamedTuple):
    """
    Output object returned when calling `reg_average(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file_location: OutputPathType
    """The averaged output file (image or affine transformation)"""


def reg_average(
    output_file: str,
    input_files: list[InputPathType],
    runner: Runner | None = None,
) -> RegAverageOutputs:
    """
    Command line program to average either images or affine transformations.
    
    Author: Marc Modat, Pankaj Daga
    
    URL: http://cmictig.cs.ucl.ac.uk/wiki/index.php/NiftyReg
    
    Args:
        output_file: Filename of the output image or affine transformation.
        input_files: Input file names (images or affine matrices) to be\
            averaged.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RegAverageOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(REG_AVERAGE_METADATA)
    cargs = []
    cargs.append("reg_average")
    cargs.append(output_file)
    cargs.extend([execution.input_file(f) for f in input_files])
    ret = RegAverageOutputs(
        root=execution.output_file("."),
        output_file_location=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "REG_AVERAGE_METADATA",
    "RegAverageOutputs",
    "reg_average",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DMASK_SVD_METADATA = Metadata(
    id="4c1694efeb80a10fd4c315f78b980a80336e0952.boutiques",
    name="3dmaskSVD",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dmaskSvdOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dmask_svd(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    svd_output: OutputPathType
    """Singular vector output redirected to this file"""


def v_3dmask_svd(
    input_dataset: InputPathType,
    runner: Runner | None = None,
) -> V3dmaskSvdOutputs:
    """
    Computes the principal singular vector of the time series vectors extracted from
    the input dataset over the input mask.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dmaskSVD.html
    
    Args:
        input_dataset: Input dataset.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dmaskSvdOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DMASK_SVD_METADATA)
    cargs = []
    cargs.append("3dmaskSVD")
    cargs.append("[OPTIONS]")
    cargs.append(execution.input_file(input_dataset))
    ret = V3dmaskSvdOutputs(
        root=execution.output_file("."),
        svd_output=execution.output_file("../stdout"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dmaskSvdOutputs",
    "V_3DMASK_SVD_METADATA",
    "v_3dmask_svd",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

AFNI_METADATA = Metadata(
    id="9989cbf73506dc9d9cd5697407857e647cc015cd.boutiques",
    name="afni",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class AfniOutputs(typing.NamedTuple):
    """
    Output object returned when calling `afni_(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    session_output: OutputPathType
    """Output file for the session data"""


def afni_(
    session_directories: str | None = None,
    runner: Runner | None = None,
) -> AfniOutputs:
    """
    Tool for reading in sessions of 3D datasets and visualizing them.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/afni.html
    
    Args:
        session_directories: Input session directories containing the datasets.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AfniOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(AFNI_METADATA)
    cargs = []
    cargs.append("afni")
    cargs.append("[OPTIONS]")
    if session_directories is not None:
        cargs.append(session_directories)
    ret = AfniOutputs(
        root=execution.output_file("."),
        session_output=execution.output_file("output_session.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "AFNI_METADATA",
    "AfniOutputs",
    "afni_",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURFACE_SET_COORDINATES_METADATA = Metadata(
    id="10e4622894f35be8d799c6136071fb0e1a9d5ed1.boutiques",
    name="surface-set-coordinates",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class SurfaceSetCoordinatesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surface_set_coordinates(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    surface_out: OutputPathType
    """the new surface"""


def surface_set_coordinates(
    surface_in: InputPathType,
    coord_metric: InputPathType,
    surface_out: str,
    runner: Runner | None = None,
) -> SurfaceSetCoordinatesOutputs:
    """
    Modify coordinates of a surface.
    
    Takes the topology from an existing surface file, and uses values from a
    metric file as coordinates to construct a new surface file.
    
    See -surface-coordinates-to-metric for how to get surface coordinates as a
    metric file, such that you can then modify them via metric commands, etc.
    
    Author: Washington University School of Medicin
    
    Args:
        surface_in: the surface to use for the topology.
        coord_metric: the new coordinates, as a 3-column metric file.
        surface_out: the new surface.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceSetCoordinatesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_SET_COORDINATES_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-set-coordinates")
    cargs.append(execution.input_file(surface_in))
    cargs.append(execution.input_file(coord_metric))
    cargs.append(surface_out)
    ret = SurfaceSetCoordinatesOutputs(
        root=execution.output_file("."),
        surface_out=execution.output_file(surface_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURFACE_SET_COORDINATES_METADATA",
    "SurfaceSetCoordinatesOutputs",
    "surface_set_coordinates",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SET_MAP_NAMES_METADATA = Metadata(
    id="b84e64ed99a4d53eca7499a7b67fae1ad3f6a9af.boutiques",
    name="set-map-names",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class SetMapNamesMap:
    """
    specify a map to set the name of.
    """
    index: int
    """the map index to change the name of"""
    new_name: str
    """the name to set for the map"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-map")
        cargs.append(str(self.index))
        cargs.append(self.new_name)
        return cargs


class SetMapNamesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `set_map_names(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def set_map_names(
    data_file: str,
    opt_name_file_file: str | None = None,
    opt_from_data_file_file: str | None = None,
    map_: list[SetMapNamesMap] | None = None,
    runner: Runner | None = None,
) -> SetMapNamesOutputs:
    """
    Set the name of one or more maps in a file.
    
    Sets the name of one or more maps for metric, shape, label, volume, cifti
    scalar or cifti label files. You must specify either -name-file, or
    -from-data-file, or at least one -map option. The three option types are
    mutually exclusive.
    
    Author: Washington University School of Medicin
    
    Args:
        data_file: the file to set the map names of.
        opt_name_file_file: use a text file to replace all map names: text file\
            containing map names, one per line.
        opt_from_data_file_file: use the map names from another data file: a\
            data file with the same number of maps.
        map_: specify a map to set the name of.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SetMapNamesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SET_MAP_NAMES_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-set-map-names")
    cargs.append(data_file)
    if opt_name_file_file is not None:
        cargs.extend([
            "-name-file",
            opt_name_file_file
        ])
    if opt_from_data_file_file is not None:
        cargs.extend([
            "-from-data-file",
            opt_from_data_file_file
        ])
    if map_ is not None:
        cargs.extend([a for c in [s.run(execution) for s in map_] for a in c])
    ret = SetMapNamesOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SET_MAP_NAMES_METADATA",
    "SetMapNamesMap",
    "SetMapNamesOutputs",
    "set_map_names",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FABBER_ASL_METADATA = Metadata(
    id="3feb317ebcb270f8e44dc9109123683428afcb5f.boutiques",
    name="fabber_asl",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FabberAslOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fabber_asl(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    logfile: OutputPathType
    """Log file of Fabber output"""
    modelfit: OutputPathType
    """Model fit output"""
    residuals: OutputPathType
    """Residuals output"""
    model_extras: OutputPathType
    """Model specific timeseries data"""
    mvn: OutputPathType
    """MVN distributions"""
    means: OutputPathType
    """Parameter means"""
    stds: OutputPathType
    """Parameter standard deviations"""
    variances: OutputPathType
    """Parameter variances"""
    zstats: OutputPathType
    """Parameter Zstats"""
    noise_means: OutputPathType
    """Noise means"""
    noise_stds: OutputPathType
    """Noise standard deviations"""
    free_energy: OutputPathType
    """Free energy"""


def fabber_asl(
    output: str,
    method: str,
    model: str,
    data: InputPathType,
    listmethods: bool = False,
    listmodels: bool = False,
    listparams: bool = False,
    descparams: bool = False,
    listoutputs: bool = False,
    evaluate: str | None = None,
    evaluate_params: str | None = None,
    evaluate_nt: float | None = None,
    simple_output: bool = False,
    overwrite: bool = False,
    link_to_latest: bool = False,
    loadmodels: InputPathType | None = None,
    mask: InputPathType | None = None,
    suppdata: InputPathType | None = None,
    dump_param_names: bool = False,
    save_model_fit: bool = False,
    save_residuals: bool = False,
    save_model_extras: bool = False,
    save_mvn: bool = False,
    save_mean: bool = False,
    save_std: bool = False,
    save_var: bool = False,
    save_zstat: bool = False,
    save_noise_mean: bool = False,
    save_noise_std: bool = False,
    save_free_energy: bool = False,
    optfile: str | None = None,
    debug: bool = False,
    runner: Runner | None = None,
) -> FabberAslOutputs:
    """
    Fabber is a tool for automated model fitting of time series data.
    
    Author: Unknown
    
    URL: https://fabber_tool.website
    
    Args:
        output: Directory for output files (including logfile).
        method: Use this inference method.
        model: Use this forward model.
        data: Specify a single input data file.
        listmethods: List all known inference methods.
        listmodels: List all known forward models.
        listparams: List model parameters (requires model configuration options\
            to be given).
        descparams: Describe model parameters (name, description, units) -\
            requires model configuration options to be given. Note that not all\
            models provide parameter descriptions.
        listoutputs: List additional model outputs (requires model\
            configuration options to be given).
        evaluate: Evaluate model. Set to name of output required or blank for\
            default output. Requires model configuration options, --evaluate-params\
            and --evaluate-nt.
        evaluate_params: List of parameter values for evaluation.
        evaluate_nt: Number of time points for evaluation - must be consistent\
            with model options where appropriate.
        simple_output: Instead of usual standard output, simply output series\
            of lines each giving progress as percentage.
        overwrite: If set will overwrite existing output. If not set, new\
            output directories will be created by appending '+' to the directory\
            name.
        link_to_latest: Try to create a link to the most recent output\
            directory with the prefix _latest.
        loadmodels: Load models dynamically from the specified filename, which\
            should be a DLL/shared library.
        mask: Mask file. Inference will only be performed where mask value > 0.
        suppdata: 'Supplemental' timeseries data, required for some models.
        dump_param_names: Write the file paramnames.txt containing the names of\
            the model parameters.
        save_model_fit: Output the model prediction as a 4d volume.
        save_residuals: Output the residuals (difference between the data and\
            the model prediction).
        save_model_extras: Output any additional model-specific timeseries data.
        save_mvn: Output the final MVN distributions.
        save_mean: Output the parameter means.
        save_std: Output the parameter standard deviations.
        save_var: Output the parameter variances.
        save_zstat: Output the parameter Zstats.
        save_noise_mean: Output the noise means. The noise distribution\
            inferred is the precision of a Gaussian noise source.
        save_noise_std: Output the noise standard deviations.
        save_free_energy: Output the free energy, if calculated.
        optfile: File containing additional options, one per line, in the same\
            form as specified on the command line.
        debug: Output large amounts of debug information. ONLY USE WITH VERY\
            SMALL NUMBERS OF VOXELS.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FabberAslOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FABBER_ASL_METADATA)
    cargs = []
    cargs.append("fabber")
    if listmethods:
        cargs.append("--listmethods")
    if listmodels:
        cargs.append("--listmodels")
    if listparams:
        cargs.append("--listparams")
    if descparams:
        cargs.append("--descparams")
    if listoutputs:
        cargs.append("--listoutputs")
    if evaluate is not None:
        cargs.append(evaluate)
    if evaluate_params is not None:
        cargs.append(evaluate_params)
    if evaluate_nt is not None:
        cargs.append(str(evaluate_nt))
    if simple_output:
        cargs.append("--simple-output")
    cargs.append(output)
    if overwrite:
        cargs.append("--overwrite")
    if link_to_latest:
        cargs.append("--link-to-latest")
    cargs.append(method)
    cargs.append(model)
    if loadmodels is not None:
        cargs.append(execution.input_file(loadmodels))
    cargs.append(execution.input_file(data))
    if mask is not None:
        cargs.append(execution.input_file(mask))
    if suppdata is not None:
        cargs.append(execution.input_file(suppdata))
    if dump_param_names:
        cargs.append("--dump-param-names")
    if save_model_fit:
        cargs.append("--save-model-fit")
    if save_residuals:
        cargs.append("--save-residuals")
    if save_model_extras:
        cargs.append("--save-model-extras")
    if save_mvn:
        cargs.append("--save-mvn")
    if save_mean:
        cargs.append("--save-mean")
    if save_std:
        cargs.append("--save-std")
    if save_var:
        cargs.append("--save-var")
    if save_zstat:
        cargs.append("--save-zstat")
    if save_noise_mean:
        cargs.append("--save-noise-mean")
    if save_noise_std:
        cargs.append("--save-noise-std")
    if save_free_energy:
        cargs.append("--save-free-energy")
    if optfile is not None:
        cargs.append(optfile)
    if debug:
        cargs.append("--debug")
    ret = FabberAslOutputs(
        root=execution.output_file("."),
        logfile=execution.output_file(output + "/logfile.txt"),
        modelfit=execution.output_file(output + "/model_fit.nii.gz"),
        residuals=execution.output_file(output + "/residuals.nii.gz"),
        model_extras=execution.output_file(output + "/extras.nii.gz"),
        mvn=execution.output_file(output + "/mvn.nii.gz"),
        means=execution.output_file(output + "/means.nii.gz"),
        stds=execution.output_file(output + "/stds.nii.gz"),
        variances=execution.output_file(output + "/variances.nii.gz"),
        zstats=execution.output_file(output + "/zstats.nii.gz"),
        noise_means=execution.output_file(output + "/noise_means.nii.gz"),
        noise_stds=execution.output_file(output + "/noise_stds.nii.gz"),
        free_energy=execution.output_file(output + "/free_energy.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FABBER_ASL_METADATA",
    "FabberAslOutputs",
    "fabber_asl",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_EIGS_TO_DT_METADATA = Metadata(
    id="121ef3bfc3e25286f4257322744aad85b76dc8ef.boutiques",
    name="3dEigsToDT",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dEigsToDtOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_eigs_to_dt(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    dt_brik_output: OutputPathType
    """Output diffusion tensor (DT) file in AFNI format (BRIK)"""
    dt_head_output: OutputPathType
    """Output diffusion tensor (DT) file in AFNI format (HEAD)"""


def v_3d_eigs_to_dt(
    eig_vals: str,
    eig_vecs: str,
    prefix: str,
    mask: InputPathType | None = None,
    flip_x: bool = False,
    flip_y: bool = False,
    flip_z: bool = False,
    scale_eigs: float | None = None,
    runner: Runner | None = None,
) -> V3dEigsToDtOutputs:
    """
    Convert set of DTI eigenvectors and eigenvalues to a diffusion tensor, with
    optional value-scaling and vector-flipping.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dEigsToDT.html
    
    Args:
        eig_vals: Searchable descriptor for finding all three required\
            eigenvalue files. It should list all three eigenvalue files in\
            descending order of magnitude.
        eig_vecs: Searchable descriptor for finding all three required\
            eigenvector files. It should list all three eigenvector files in order\
            matching the eigenvalue files.
        prefix: Prefix for the output file name. It is recommended to include a\
            'DT' label in it.
        mask: Optional mask within which to calculate uncertainty. If not\
            provided, the data should be masked already.
        flip_x: Change sign of the first element of eigenvectors.
        flip_y: Change sign of the second element of eigenvectors.
        flip_z: Change sign of the third element of eigenvectors.
        scale_eigs: Rescale the eigenvalues by dividing by a number X > 0.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dEigsToDtOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_EIGS_TO_DT_METADATA)
    cargs = []
    cargs.append("3dEigsToDT")
    cargs.append("-eig_vals")
    cargs.append(eig_vals)
    cargs.append("-eig_vecs")
    cargs.append(eig_vecs)
    cargs.append("-prefix")
    cargs.append(prefix)
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if flip_x:
        cargs.append("-flip_x")
    if flip_y:
        cargs.append("-flip_y")
    if flip_z:
        cargs.append("-flip_z")
    if scale_eigs is not None:
        cargs.extend([
            "-scale_eigs",
            str(scale_eigs)
        ])
    ret = V3dEigsToDtOutputs(
        root=execution.output_file("."),
        dt_brik_output=execution.output_file(prefix + "_DT+orig.BRIK"),
        dt_head_output=execution.output_file(prefix + "_DT+orig.HEAD"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dEigsToDtOutputs",
    "V_3D_EIGS_TO_DT_METADATA",
    "v_3d_eigs_to_dt",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FAT_MAT_TABLEIZE_PY_METADATA = Metadata(
    id="087a0494cbbc551153bb18291702595477bae363.boutiques",
    name="fat_mat_tableize.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class FatMatTableizePyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fat_mat_tableize_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_table: OutputPathType
    """Table file usable in AFNI group analysis programs."""
    output_log: OutputPathType
    """Log file reporting inputs, matching, and aspects of creating the table
    file."""


def fat_mat_tableize_py(
    runner: Runner | None = None,
) -> FatMatTableizePyOutputs:
    """
    Make tables for AFNI group analysis programs from 3dNetCorr (*.netcc) and
    3dTrackID (*.grid) outputs, with optional additional subject information from
    CSV files.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/fat_mat_tableize.py.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FatMatTableizePyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FAT_MAT_TABLEIZE_PY_METADATA)
    cargs = []
    cargs.append("fat_mat_tableize.py")
    cargs.append("[-in_mat")
    cargs.append("INPUT_MATRICES]")
    cargs.append("[-in_csv")
    cargs.append("INPUT_CSV]")
    cargs.append("[-in_listfile")
    cargs.append("INPUT_LIST]")
    cargs.append("[-prefix")
    cargs.append("OUTPUT_PREFIX]")
    cargs.append("[-pars")
    cargs.append("PARAMETERS]")
    cargs.append("[-ver]")
    cargs.append("[-date]")
    cargs.append("[-help]")
    cargs.append("[-h]")
    cargs.append("[-hview]")
    ret = FatMatTableizePyOutputs(
        root=execution.output_file("."),
        output_table=execution.output_file("[OUTPUT_PREFIX]_tbl.txt"),
        output_log=execution.output_file("[OUTPUT_PREFIX]_prep.log"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FAT_MAT_TABLEIZE_PY_METADATA",
    "FatMatTableizePyOutputs",
    "fat_mat_tableize_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

NICCC_METADATA = Metadata(
    id="d138035fa76e2880239e1ebb0517f36ddc0b13fa.boutiques",
    name="niccc",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class NicccOutputs(typing.NamedTuple):
    """
    Output object returned when calling `niccc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    stderr_output: OutputPathType
    """Results output to stderr"""


def niccc(
    streamspec: str,
    runner: Runner | None = None,
) -> NicccOutputs:
    """
    A program for conducting certain NIML tests on input from streamspec and write
    the results to stderr.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/niccc.html
    
    Args:
        streamspec: A string defining a NIML stream.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `NicccOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(NICCC_METADATA)
    cargs = []
    cargs.append("niccc")
    cargs.append("[OPTIONS]")
    cargs.append(streamspec)
    ret = NicccOutputs(
        root=execution.output_file("."),
        stderr_output=execution.output_file("stderr"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "NICCC_METADATA",
    "NicccOutputs",
    "niccc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CONVERTWARP_METADATA = Metadata(
    id="72b8c95c9bb70bd2c1483db87cbd13ddbdf4d26c.boutiques",
    name="convertwarp",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class ConvertwarpOutputs(typing.NamedTuple):
    """
    Output object returned when calling `convertwarp(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_warp_file: OutputPathType
    """Output warp image"""


def convertwarp(
    output_warp: str,
    refvol: InputPathType,
    premat: InputPathType | None = None,
    warp1: InputPathType | None = None,
    midmat: InputPathType | None = None,
    warp2: InputPathType | None = None,
    postmat: InputPathType | None = None,
    shiftmap: InputPathType | None = None,
    shiftdir: typing.Literal["x", "y", "z", "x-", "y-", "z-"] | None = None,
    jacobian: bool = False,
    jstats: bool = False,
    constrainj: bool = False,
    jmin: float | None = None,
    jmax: float | None = None,
    abs_: bool = False,
    rel: bool = False,
    absout: bool = False,
    relout: bool = False,
    verbose: bool = False,
    runner: Runner | None = None,
) -> ConvertwarpOutputs:
    """
    Convert and combine FSL warp fields.
    
    Author: University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk
    
    Args:
        output_warp: Filename for output (warp) image - always in 'field'\
            format.
        refvol: Filename for reference image.
        premat: Filename of pre-affine transform.
        warp1: Filename for initial warp (follows pre-affine).
        midmat: Filename of mid-warp-affine transform.
        warp2: Filename for secondary warp (after initial warp, before\
            post-affine).
        postmat: Filename of post-affine transform.
        shiftmap: Filename for shiftmap (applied first).
        shiftdir: Direction to apply shiftmap {x,y,z,x-,y-,z-}.
        jacobian: Calculate and save Jacobian of final warp field.
        jstats: Print out statistics of the Jacobian of the warpfield.
        constrainj: Constrain the Jacobian of the warpfield to lie within\
            specified min/max limits.
        jmin: Minimum acceptable Jacobian value for constraint (default 0.01).
        jmax: Maximum acceptable Jacobian value for constraint (default 100.0).
        abs_: Use absolute warp convention (default): x' = w(x).
        rel: Use relative warp convention: x' = x + w(x).
        absout: Force output to use absolute warp convention: x' = w(x).
        relout: Force output to use relative warp convention: x' = x + w(x).
        verbose: Switch on diagnostic messages.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ConvertwarpOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CONVERTWARP_METADATA)
    cargs = []
    cargs.append("convertwarp")
    cargs.extend([
        "-o",
        output_warp
    ])
    cargs.extend([
        "-r",
        execution.input_file(refvol)
    ])
    if premat is not None:
        cargs.extend([
            "-m",
            execution.input_file(premat)
        ])
    if warp1 is not None:
        cargs.extend([
            "-w",
            execution.input_file(warp1)
        ])
    if midmat is not None:
        cargs.extend([
            "--midmat",
            execution.input_file(midmat)
        ])
    if warp2 is not None:
        cargs.extend([
            "--warp2",
            execution.input_file(warp2)
        ])
    if postmat is not None:
        cargs.extend([
            "--postmat",
            execution.input_file(postmat)
        ])
    if shiftmap is not None:
        cargs.extend([
            "-s",
            execution.input_file(shiftmap)
        ])
    if shiftdir is not None:
        cargs.extend([
            "-d",
            shiftdir
        ])
    if jacobian:
        cargs.append("-j")
    if jstats:
        cargs.append("--jstats")
    if constrainj:
        cargs.append("--constrainj")
    if jmin is not None:
        cargs.extend([
            "--jmin",
            str(jmin)
        ])
    if jmax is not None:
        cargs.extend([
            "--jmax",
            str(jmax)
        ])
    if abs_:
        cargs.append("--abs")
    if rel:
        cargs.append("--rel")
    if absout:
        cargs.append("--absout")
    if relout:
        cargs.append("--relout")
    if verbose:
        cargs.append("-v")
    ret = ConvertwarpOutputs(
        root=execution.output_file("."),
        output_warp_file=execution.output_file(output_warp),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CONVERTWARP_METADATA",
    "ConvertwarpOutputs",
    "convertwarp",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MERGE_MRS_REPORTS_METADATA = Metadata(
    id="46e7fcc93e4f7333a7cd394c4e03c2819a40016b.boutiques",
    name="merge_mrs_reports",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class MergeMrsReportsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `merge_mrs_reports(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    merged_output_file: OutputPathType | None
    """Merged HTML report"""


def merge_mrs_reports(
    input_files: list[InputPathType],
    dataset_description: str,
    output_folder: str | None = None,
    output_filename: str | None = None,
    delete_flag: bool = False,
    runner: Runner | None = None,
) -> MergeMrsReportsOutputs:
    """
    FSL Magnetic Resonance Spectroscopy - Merge HTML reports based on filename in
    directory.
    
    Author: FSL
    
    Args:
        input_files: List of input files.
        dataset_description: Dataset description.
        output_folder: Output folder (default=current directory).
        output_filename: Output filename (default=mergedReports.html).
        delete_flag: Delete files after successful merge.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MergeMrsReportsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MERGE_MRS_REPORTS_METADATA)
    cargs = []
    cargs.append("merge_mrs_reports")
    cargs.extend([execution.input_file(f) for f in input_files])
    cargs.append("--description")
    cargs.extend([
        "-d",
        dataset_description
    ])
    if output_folder is not None:
        cargs.extend([
            "-o",
            output_folder
        ])
    if output_filename is not None:
        cargs.extend([
            "-f",
            output_filename
        ])
    if delete_flag:
        cargs.append("--delete")
    ret = MergeMrsReportsOutputs(
        root=execution.output_file("."),
        merged_output_file=execution.output_file(output_folder + "/" + output_filename) if (output_folder is not None and output_filename is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MERGE_MRS_REPORTS_METADATA",
    "MergeMrsReportsOutputs",
    "merge_mrs_reports",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

METRIC_FILL_HOLES_METADATA = Metadata(
    id="01f9f706378f6ba0092f279b104ef0c8e161e9ce.boutiques",
    name="metric-fill-holes",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class MetricFillHolesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `metric_fill_holes(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output ROI metric"""


def metric_fill_holes(
    surface: InputPathType,
    metric_in: InputPathType,
    metric_out: str,
    opt_corrected_areas_area_metric: InputPathType | None = None,
    runner: Runner | None = None,
) -> MetricFillHolesOutputs:
    """
    Fill holes in an roi metric.
    
    Finds all connected areas that are not included in the ROI, and writes ones
    into all but the largest one, in terms of surface area.
    
    Author: Washington University School of Medicin
    
    Args:
        surface: the surface to use for neighbor information.
        metric_in: the input ROI metric.
        metric_out: the output ROI metric.
        opt_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the surface: the corrected vertex areas, as a\
            metric.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricFillHolesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(METRIC_FILL_HOLES_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-metric-fill-holes")
    cargs.append(execution.input_file(surface))
    cargs.append(execution.input_file(metric_in))
    cargs.append(metric_out)
    if opt_corrected_areas_area_metric is not None:
        cargs.extend([
            "-corrected-areas",
            execution.input_file(opt_corrected_areas_area_metric)
        ])
    ret = MetricFillHolesOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(metric_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "METRIC_FILL_HOLES_METADATA",
    "MetricFillHolesOutputs",
    "metric_fill_holes",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DANISOSMOOTH_METADATA = Metadata(
    id="f9ebe5fa3b013bdcb909e178c9093254c20aada2.boutiques",
    name="3danisosmooth",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3danisosmoothOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3danisosmooth(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dataset: OutputPathType
    """Output dataset after anisotropic smoothing"""
    gradient_data: OutputPathType
    """Gradient dataset saved at each iteration"""
    eigens_data: OutputPathType
    """Eigens dataset saved at each iteration"""
    phi_data: OutputPathType
    """Phi dataset saved at each iteration"""
    dtensor_data: OutputPathType
    """Dtensor dataset saved at each iteration"""
    ematrix_data: OutputPathType
    """Ematrix dataset saved at the first sub-brick iteration"""
    flux_data: OutputPathType
    """Flux dataset saved at the first sub-brick iteration"""
    gmatrix_data: OutputPathType
    """Gmatrix dataset saved at the first sub-brick iteration"""
    diff_measures_data: OutputPathType
    """Dataset containing FA, MD, Cl, Cp, and Cs values saved at each
    iteration"""


def v_3danisosmooth(
    input_dataset: InputPathType,
    runner: Runner | None = None,
) -> V3danisosmoothOutputs:
    """
    Smooths a dataset using an anisotropic smoothing technique.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3danisosmooth.html
    
    Args:
        input_dataset: Input dataset to be smoothed.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3danisosmoothOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DANISOSMOOTH_METADATA)
    cargs = []
    cargs.append("3danisosmooth")
    cargs.append("[OPTIONS]")
    cargs.append(execution.input_file(input_dataset))
    ret = V3danisosmoothOutputs(
        root=execution.output_file("."),
        output_dataset=execution.output_file("[PREFIX]+smooth"),
        gradient_data=execution.output_file("Gradient.ITER"),
        eigens_data=execution.output_file("Eigens.ITER"),
        phi_data=execution.output_file("phi.ITER"),
        dtensor_data=execution.output_file("Dtensor.ITER"),
        ematrix_data=execution.output_file("Ematrix.ITER"),
        flux_data=execution.output_file("Flux.ITER"),
        gmatrix_data=execution.output_file("Gmatrix.ITER"),
        diff_measures_data=execution.output_file("Diff_measures.ITER"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3danisosmoothOutputs",
    "V_3DANISOSMOOTH_METADATA",
    "v_3danisosmooth",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CONVERT_XFM_METADATA = Metadata(
    id="33725cbe84b723f9171fabf007a4747024370859.boutiques",
    name="convert_xfm",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class ConvertXfmOutputs(typing.NamedTuple):
    """
    Output object returned when calling `convert_xfm(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_trasnformation: OutputPathType | None
    """Output transformation matrix."""


def convert_xfm(
    in_file: InputPathType,
    invert_xfm: bool = False,
    concat_xfm: InputPathType | None = None,
    fix_scale_skew: InputPathType | None = None,
    out_file: InputPathType | None = None,
    runner: Runner | None = None,
) -> ConvertXfmOutputs:
    """
    convert_xfm is a utility that is used to convert between different
    transformation file formats. It can read and write ascii 4x4 matrices. In
    addition, it can be used to concatenate two transforms (using -concat with the
    second transform) or to find the inverse transformation (using -inverse).
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FLIRT/UserGuide#convert_xfm
    
    Args:
        in_file: Input transformation matrix.
        invert_xfm: Invert input transformation.
        concat_xfm: A File. Write joint transformation of two input matrices.
        fix_scale_skew: A File. Use secondary matrix to fix scale and skew.
        out_file: Final transformation matrix.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ConvertXfmOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CONVERT_XFM_METADATA)
    cargs = []
    cargs.append("convert_xfm")
    cargs.append(execution.input_file(in_file))
    if invert_xfm:
        cargs.append("-inverse")
    if concat_xfm is not None:
        cargs.extend([
            "-concat",
            execution.input_file(concat_xfm)
        ])
    if fix_scale_skew is not None:
        cargs.extend([
            "-fixscaleskew",
            execution.input_file(fix_scale_skew)
        ])
    if out_file is not None:
        cargs.extend([
            "-omat",
            execution.input_file(out_file)
        ])
    ret = ConvertXfmOutputs(
        root=execution.output_file("."),
        output_trasnformation=execution.output_file(pathlib.Path(out_file).name) if (out_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CONVERT_XFM_METADATA",
    "ConvertXfmOutputs",
    "convert_xfm",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

IMCAT_METADATA = Metadata(
    id="06c193024d85eb1fc0a4565a8c2621e9cd4661df.boutiques",
    name="imcat",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class ImcatOutputs(typing.NamedTuple):
    """
    Output object returned when calling `imcat(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_image_file: OutputPathType | None
    """Output image file"""


def imcat(
    scale_image: InputPathType | None = None,
    scale_pixels: InputPathType | None = None,
    scale_intensity: bool = False,
    rgb_out: bool = False,
    res_in: list[float] | None = None,
    respad_in: list[float] | None = None,
    pad_val: float | None = None,
    crop: list[float] | None = None,
    autocrop_ctol: float | None = None,
    autocrop_atol: float | None = None,
    autocrop: bool = False,
    zero_wrap: bool = False,
    white_wrap: bool = False,
    gray_wrap: float | None = None,
    image_wrap: bool = False,
    rand_wrap: bool = False,
    prefix: str | None = None,
    matrix: list[float] | None = None,
    nx: float | None = None,
    ny: float | None = None,
    matrix_from_scale: bool = False,
    gap: float | None = None,
    gap_col: list[float] | None = None,
    runner: Runner | None = None,
) -> ImcatOutputs:
    """
    Assembles a set of images into an image matrix (IM) montage of NX by NY images.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/imcat.html
    
    Args:
        scale_image: Multiply each image IM(i,j) in output image matrix IM by\
            the color or intensity of the pixel (i,j) in SCALE_IMG.
        scale_pixels: Multiply each pixel (i,j) in output image by the color or\
            intensity of the pixel (i,j) in SCALE_IMG. SCALE_IMG is automatically\
            resized to the resolution of the output image.
        scale_intensity: Instead of multiplying by the color of pixel (i,j),\
            use its intensity (average color).
        rgb_out: Force output to be in RGB, even if input is bytes. This option\
            is turned on automatically in certain cases.
        res_in: Set resolution of all input images to RX by RY pixels. Default\
            is to make all input have the same resolution as the first image.
        respad_in: Like -res_in, but resample to the max while respecting the\
            aspect ratio, and then pad to achieve desired pixel count.
        pad_val: Set the padding value, should it be needed by -respad_in to\
            VAL. VAL is typecast to byte, default is 0, max is 255.
        crop: Crop images by L (Left), R (Right), T (Top), B (Bottom) pixels.\
            Cutting is performed after any resolution change, if any, is to be\
            done.
        autocrop_ctol: A line is eliminated if none of its R G B values differ\
            by more than CTOL% from those of the corner pixel.
        autocrop_atol: A line is eliminated if none of its R G B values differ\
            by more than ATOL% from those of line average.
        autocrop: This option is the same as using both of -autocrop_atol 20\
            and -autocrop_ctol 20.
        zero_wrap: If number of images is not enough to fill matrix solid black\
            images are used.
        white_wrap: If number of images is not enough to fill matrix solid\
            white images are used.
        gray_wrap: If number of images is not enough to fill matrix, solid gray\
            images are used. GRAY must be between 0 and 1.0.
        image_wrap: If number of images is not enough to fill matrix, images on\
            command line are reused (default).
        rand_wrap: When reusing images to fill matrix, randomize the order in\
            refill section only.
        prefix: Prefix the output files with string 'ppp'.
        matrix: Specify number of images in each row and column of IM at the\
            same time.
        nx: Number of images in each row.
        ny: Number of images in each column.
        matrix_from_scale: Set NX and NY to be the same as the SCALE_IMG's\
            dimensions. (needs -scale_image).
        gap: Put a line G pixels wide between images.
        gap_col: Set color of line to R G B values. Values range between 0 and\
            255.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ImcatOutputs`).
    """
    if pad_val is not None and not (0 <= pad_val <= 255): 
        raise ValueError(f"'pad_val' must be between 0 <= x <= 255 but was {pad_val}")
    if gray_wrap is not None and not (0.0 <= gray_wrap <= 1.0): 
        raise ValueError(f"'gray_wrap' must be between 0.0 <= x <= 1.0 but was {gray_wrap}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(IMCAT_METADATA)
    cargs = []
    cargs.append("2dcat")
    if scale_image is not None:
        cargs.extend([
            "-scale_image",
            execution.input_file(scale_image)
        ])
    if scale_pixels is not None:
        cargs.extend([
            "-scale_pixels",
            execution.input_file(scale_pixels)
        ])
    if scale_intensity:
        cargs.append("-scale_intensity")
    cargs.append("[GSCLAE]")
    if rgb_out:
        cargs.append("-rgb_out")
    if res_in is not None:
        cargs.extend([
            "-res_in",
            *map(str, res_in)
        ])
    if respad_in is not None:
        cargs.extend([
            "-respad_in",
            *map(str, respad_in)
        ])
    if pad_val is not None:
        cargs.extend([
            "-pad_val",
            str(pad_val)
        ])
    if crop is not None:
        cargs.extend([
            "-crop",
            *map(str, crop)
        ])
    if autocrop_ctol is not None:
        cargs.extend([
            "-autocrop_ctol",
            str(autocrop_ctol)
        ])
    if autocrop_atol is not None:
        cargs.extend([
            "-autocrop_atol",
            str(autocrop_atol)
        ])
    if autocrop:
        cargs.append("-autocrop")
    if zero_wrap:
        cargs.append("-zero_wrap")
    if white_wrap:
        cargs.append("-white_wrap")
    if gray_wrap is not None:
        cargs.extend([
            "-gray_wrap",
            str(gray_wrap)
        ])
    if image_wrap:
        cargs.append("-image_wrap")
    if rand_wrap:
        cargs.append("-rand_wrap")
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if matrix is not None:
        cargs.extend([
            "-matrix",
            *map(str, matrix)
        ])
    if nx is not None:
        cargs.extend([
            "-nx",
            str(nx)
        ])
    if ny is not None:
        cargs.extend([
            "-ny",
            str(ny)
        ])
    if matrix_from_scale:
        cargs.append("-matrix_from_scale")
    if gap is not None:
        cargs.extend([
            "-gap",
            str(gap)
        ])
    if gap_col is not None:
        cargs.extend([
            "-gap_col",
            *map(str, gap_col)
        ])
    cargs.append("[INPUT_FILES...]")
    ret = ImcatOutputs(
        root=execution.output_file("."),
        output_image_file=execution.output_file(prefix + "output_image.[EXT]") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "IMCAT_METADATA",
    "ImcatOutputs",
    "imcat",
]
